# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: etcd/etcdserver/etcdserverpb/rpc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from etcd.storage.storagepb import kv_pb2 as etcd_dot_storage_dot_storagepb_dot_kv__pb2
from etcd.auth.authpb import auth_pb2 as etcd_dot_auth_dot_authpb_dot_auth__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='etcd/etcdserver/etcdserverpb/rpc.proto',
  package='etcdserverpb',
  syntax='proto3',
  serialized_pb=_b('\n&etcd/etcdserver/etcdserverpb/rpc.proto\x12\x0c\x65tcdserverpb\x1a\x14gogoproto/gogo.proto\x1a\x1f\x65tcd/storage/storagepb/kv.proto\x1a\x1b\x65tcd/auth/authpb/auth.proto\"\\\n\x0eResponseHeader\x12\x12\n\ncluster_id\x18\x01 \x01(\x04\x12\x11\n\tmember_id\x18\x02 \x01(\x04\x12\x10\n\x08revision\x18\x03 \x01(\x03\x12\x11\n\traft_term\x18\x04 \x01(\x04\"\xcf\x02\n\x0cRangeRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x11\n\trange_end\x18\x02 \x01(\x0c\x12\r\n\x05limit\x18\x03 \x01(\x03\x12\x10\n\x08revision\x18\x04 \x01(\x03\x12\x38\n\nsort_order\x18\x05 \x01(\x0e\x32$.etcdserverpb.RangeRequest.SortOrder\x12:\n\x0bsort_target\x18\x06 \x01(\x0e\x32%.etcdserverpb.RangeRequest.SortTarget\x12\x14\n\x0cserializable\x18\x07 \x01(\x08\".\n\tSortOrder\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x41SCEND\x10\x01\x12\x0b\n\x07\x44\x45SCEND\x10\x02\"B\n\nSortTarget\x12\x07\n\x03KEY\x10\x00\x12\x0b\n\x07VERSION\x10\x01\x12\n\n\x06\x43REATE\x10\x02\x12\x07\n\x03MOD\x10\x03\x12\t\n\x05VALUE\x10\x04\"m\n\rRangeResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12 \n\x03kvs\x18\x02 \x03(\x0b\x32\x13.storagepb.KeyValue\x12\x0c\n\x04more\x18\x03 \x01(\x08\"7\n\nPutRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\r\n\x05lease\x18\x03 \x01(\x03\";\n\x0bPutResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"4\n\x12\x44\x65leteRangeRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x11\n\trange_end\x18\x02 \x01(\x0c\"T\n\x13\x44\x65leteRangeResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x0f\n\x07\x64\x65leted\x18\x02 \x01(\x03\"\xc1\x01\n\x0cRequestUnion\x12\x33\n\rrequest_range\x18\x01 \x01(\x0b\x32\x1a.etcdserverpb.RangeRequestH\x00\x12/\n\x0brequest_put\x18\x02 \x01(\x0b\x32\x18.etcdserverpb.PutRequestH\x00\x12@\n\x14request_delete_range\x18\x03 \x01(\x0b\x32 .etcdserverpb.DeleteRangeRequestH\x00\x42\t\n\x07request\"\xc9\x01\n\rResponseUnion\x12\x35\n\x0eresponse_range\x18\x01 \x01(\x0b\x32\x1b.etcdserverpb.RangeResponseH\x00\x12\x31\n\x0cresponse_put\x18\x02 \x01(\x0b\x32\x19.etcdserverpb.PutResponseH\x00\x12\x42\n\x15response_delete_range\x18\x03 \x01(\x0b\x32!.etcdserverpb.DeleteRangeResponseH\x00\x42\n\n\x08response\"\xd8\x02\n\x07\x43ompare\x12\x33\n\x06result\x18\x01 \x01(\x0e\x32#.etcdserverpb.Compare.CompareResult\x12\x33\n\x06target\x18\x02 \x01(\x0e\x32#.etcdserverpb.Compare.CompareTarget\x12\x0b\n\x03key\x18\x03 \x01(\x0c\x12\x11\n\x07version\x18\x04 \x01(\x03H\x00\x12\x19\n\x0f\x63reate_revision\x18\x05 \x01(\x03H\x00\x12\x16\n\x0cmod_revision\x18\x06 \x01(\x03H\x00\x12\x0f\n\x05value\x18\x07 \x01(\x0cH\x00\"1\n\rCompareResult\x12\t\n\x05\x45QUAL\x10\x00\x12\x0b\n\x07GREATER\x10\x01\x12\x08\n\x04LESS\x10\x02\"<\n\rCompareTarget\x12\x0b\n\x07VERSION\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x07\n\x03MOD\x10\x02\x12\t\n\x05VALUE\x10\x03\x42\x0e\n\x0ctarget_union\"\x8e\x01\n\nTxnRequest\x12&\n\x07\x63ompare\x18\x01 \x03(\x0b\x32\x15.etcdserverpb.Compare\x12+\n\x07success\x18\x02 \x03(\x0b\x32\x1a.etcdserverpb.RequestUnion\x12+\n\x07\x66\x61ilure\x18\x03 \x03(\x0b\x32\x1a.etcdserverpb.RequestUnion\"~\n\x0bTxnResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x11\n\tsucceeded\x18\x02 \x01(\x08\x12.\n\tresponses\x18\x03 \x03(\x0b\x32\x1b.etcdserverpb.ResponseUnion\"7\n\x11\x43ompactionRequest\x12\x10\n\x08revision\x18\x01 \x01(\x03\x12\x10\n\x08physical\x18\x02 \x01(\x08\"B\n\x12\x43ompactionResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"\r\n\x0bHashRequest\"J\n\x0cHashResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x0c\n\x04hash\x18\x02 \x01(\r\"\x11\n\x0fSnapshotRequest\"g\n\x10SnapshotResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x17\n\x0fremaining_bytes\x18\x02 \x01(\x04\x12\x0c\n\x04\x62lob\x18\x03 \x01(\x0c\"\x97\x01\n\x0cWatchRequest\x12:\n\x0e\x63reate_request\x18\x01 \x01(\x0b\x32 .etcdserverpb.WatchCreateRequestH\x00\x12:\n\x0e\x63\x61ncel_request\x18\x02 \x01(\x0b\x32 .etcdserverpb.WatchCancelRequestH\x00\x42\x0f\n\rrequest_union\"e\n\x12WatchCreateRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x11\n\trange_end\x18\x02 \x01(\x0c\x12\x16\n\x0estart_revision\x18\x03 \x01(\x03\x12\x17\n\x0fprogress_notify\x18\x04 \x01(\x08\"&\n\x12WatchCancelRequest\x12\x10\n\x08watch_id\x18\x01 \x01(\x03\"\xae\x01\n\rWatchResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x10\n\x08watch_id\x18\x02 \x01(\x03\x12\x0f\n\x07\x63reated\x18\x03 \x01(\x08\x12\x10\n\x08\x63\x61nceled\x18\x04 \x01(\x08\x12\x18\n\x10\x63ompact_revision\x18\x05 \x01(\x03\x12 \n\x06\x65vents\x18\x0b \x03(\x0b\x32\x10.storagepb.Event\",\n\x11LeaseGrantRequest\x12\x0b\n\x03TTL\x18\x01 \x01(\x03\x12\n\n\x02ID\x18\x02 \x01(\x03\"j\n\x12LeaseGrantResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\n\n\x02ID\x18\x02 \x01(\x03\x12\x0b\n\x03TTL\x18\x03 \x01(\x03\x12\r\n\x05\x65rror\x18\x04 \x01(\t\" \n\x12LeaseRevokeRequest\x12\n\n\x02ID\x18\x01 \x01(\x03\"C\n\x13LeaseRevokeResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"#\n\x15LeaseKeepAliveRequest\x12\n\n\x02ID\x18\x01 \x01(\x03\"_\n\x16LeaseKeepAliveResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\n\n\x02ID\x18\x02 \x01(\x03\x12\x0b\n\x03TTL\x18\x03 \x01(\x03\"H\n\x06Member\x12\n\n\x02ID\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08peerURLs\x18\x03 \x03(\t\x12\x12\n\nclientURLs\x18\x04 \x03(\t\"$\n\x10MemberAddRequest\x12\x10\n\x08peerURLs\x18\x01 \x03(\t\"g\n\x11MemberAddResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12$\n\x06member\x18\x02 \x01(\x0b\x32\x14.etcdserverpb.Member\"!\n\x13MemberRemoveRequest\x12\n\n\x02ID\x18\x01 \x01(\x04\"D\n\x14MemberRemoveResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"3\n\x13MemberUpdateRequest\x12\n\n\x02ID\x18\x01 \x01(\x04\x12\x10\n\x08peerURLs\x18\x02 \x03(\t\"D\n\x14MemberUpdateResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"\x13\n\x11MemberListRequest\"i\n\x12MemberListResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12%\n\x07members\x18\x02 \x03(\x0b\x32\x14.etcdserverpb.Member\"\x13\n\x11\x44\x65\x66ragmentRequest\"B\n\x12\x44\x65\x66ragmentResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"\xb6\x01\n\x0c\x41larmRequest\x12\x36\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32&.etcdserverpb.AlarmRequest.AlarmAction\x12\x10\n\x08memberID\x18\x02 \x01(\x04\x12&\n\x05\x61larm\x18\x03 \x01(\x0e\x32\x17.etcdserverpb.AlarmType\"4\n\x0b\x41larmAction\x12\x07\n\x03GET\x10\x00\x12\x0c\n\x08\x41\x43TIVATE\x10\x01\x12\x0e\n\nDEACTIVATE\x10\x02\"G\n\x0b\x41larmMember\x12\x10\n\x08memberID\x18\x01 \x01(\x04\x12&\n\x05\x61larm\x18\x02 \x01(\x0e\x32\x17.etcdserverpb.AlarmType\"h\n\rAlarmResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12)\n\x06\x61larms\x18\x02 \x03(\x0b\x32\x19.etcdserverpb.AlarmMember\"\x0f\n\rStatusRequest\"\x94\x01\n\x0eStatusResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0e\n\x06\x64\x62Size\x18\x03 \x01(\x03\x12\x0e\n\x06leader\x18\x04 \x01(\x04\x12\x11\n\traftIndex\x18\x05 \x01(\x04\x12\x10\n\x08raftTerm\x18\x06 \x01(\x04\"\x13\n\x11\x41uthEnableRequest\"\x14\n\x12\x41uthDisableRequest\"5\n\x13\x41uthenticateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"4\n\x12\x41uthUserAddRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\x14\n\x12\x41uthUserGetRequest\"%\n\x15\x41uthUserDeleteRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"?\n\x1d\x41uthUserChangePasswordRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"2\n\x14\x41uthUserGrantRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\"\x17\n\x15\x41uthUserRevokeRequest\"\"\n\x12\x41uthRoleAddRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x14\n\x12\x41uthRoleGetRequest\"\x17\n\x15\x41uthRoleDeleteRequest\"F\n\x14\x41uthRoleGrantRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x04perm\x18\x02 \x01(\x0b\x32\x12.authpb.Permission\"\x17\n\x15\x41uthRoleRevokeRequest\"B\n\x12\x41uthEnableResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"C\n\x13\x41uthDisableResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"S\n\x14\x41uthenticateResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\r\n\x05token\x18\x02 \x01(\t\"C\n\x13\x41uthUserAddResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"C\n\x13\x41uthUserGetResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"F\n\x16\x41uthUserDeleteResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"N\n\x1e\x41uthUserChangePasswordResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"E\n\x15\x41uthUserGrantResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"F\n\x16\x41uthUserRevokeResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"C\n\x13\x41uthRoleAddResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"C\n\x13\x41uthRoleGetResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"F\n\x16\x41uthRoleDeleteResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"E\n\x15\x41uthRoleGrantResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"F\n\x16\x41uthRoleRevokeResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader*\"\n\tAlarmType\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07NOSPACE\x10\x01\x32\xea\x02\n\x02KV\x12\x42\n\x05Range\x12\x1a.etcdserverpb.RangeRequest\x1a\x1b.etcdserverpb.RangeResponse\"\x00\x12<\n\x03Put\x12\x18.etcdserverpb.PutRequest\x1a\x19.etcdserverpb.PutResponse\"\x00\x12T\n\x0b\x44\x65leteRange\x12 .etcdserverpb.DeleteRangeRequest\x1a!.etcdserverpb.DeleteRangeResponse\"\x00\x12<\n\x03Txn\x12\x18.etcdserverpb.TxnRequest\x1a\x19.etcdserverpb.TxnResponse\"\x00\x12N\n\x07\x43ompact\x12\x1f.etcdserverpb.CompactionRequest\x1a .etcdserverpb.CompactionResponse\"\x00\x32O\n\x05Watch\x12\x46\n\x05Watch\x12\x1a.etcdserverpb.WatchRequest\x1a\x1b.etcdserverpb.WatchResponse\"\x00(\x01\x30\x01\x32\x93\x02\n\x05Lease\x12Q\n\nLeaseGrant\x12\x1f.etcdserverpb.LeaseGrantRequest\x1a .etcdserverpb.LeaseGrantResponse\"\x00\x12T\n\x0bLeaseRevoke\x12 .etcdserverpb.LeaseRevokeRequest\x1a!.etcdserverpb.LeaseRevokeResponse\"\x00\x12\x61\n\x0eLeaseKeepAlive\x12#.etcdserverpb.LeaseKeepAliveRequest\x1a$.etcdserverpb.LeaseKeepAliveResponse\"\x00(\x01\x30\x01\x32\xde\x02\n\x07\x43luster\x12N\n\tMemberAdd\x12\x1e.etcdserverpb.MemberAddRequest\x1a\x1f.etcdserverpb.MemberAddResponse\"\x00\x12W\n\x0cMemberRemove\x12!.etcdserverpb.MemberRemoveRequest\x1a\".etcdserverpb.MemberRemoveResponse\"\x00\x12W\n\x0cMemberUpdate\x12!.etcdserverpb.MemberUpdateRequest\x1a\".etcdserverpb.MemberUpdateResponse\"\x00\x12Q\n\nMemberList\x12\x1f.etcdserverpb.MemberListRequest\x1a .etcdserverpb.MemberListResponse\"\x00\x32\xfb\x02\n\x0bMaintenance\x12\x42\n\x05\x41larm\x12\x1a.etcdserverpb.AlarmRequest\x1a\x1b.etcdserverpb.AlarmResponse\"\x00\x12\x45\n\x06Status\x12\x1b.etcdserverpb.StatusRequest\x1a\x1c.etcdserverpb.StatusResponse\"\x00\x12Q\n\nDefragment\x12\x1f.etcdserverpb.DefragmentRequest\x1a .etcdserverpb.DefragmentResponse\"\x00\x12?\n\x04Hash\x12\x19.etcdserverpb.HashRequest\x1a\x1a.etcdserverpb.HashResponse\"\x00\x12M\n\x08Snapshot\x12\x1d.etcdserverpb.SnapshotRequest\x1a\x1e.etcdserverpb.SnapshotResponse\"\x00\x30\x01\x32\xdf\t\n\x04\x41uth\x12Q\n\nAuthEnable\x12\x1f.etcdserverpb.AuthEnableRequest\x1a .etcdserverpb.AuthEnableResponse\"\x00\x12T\n\x0b\x41uthDisable\x12 .etcdserverpb.AuthDisableRequest\x1a!.etcdserverpb.AuthDisableResponse\"\x00\x12W\n\x0c\x41uthenticate\x12!.etcdserverpb.AuthenticateRequest\x1a\".etcdserverpb.AuthenticateResponse\"\x00\x12P\n\x07UserAdd\x12 .etcdserverpb.AuthUserAddRequest\x1a!.etcdserverpb.AuthUserAddResponse\"\x00\x12P\n\x07UserGet\x12 .etcdserverpb.AuthUserGetRequest\x1a!.etcdserverpb.AuthUserGetResponse\"\x00\x12Y\n\nUserDelete\x12#.etcdserverpb.AuthUserDeleteRequest\x1a$.etcdserverpb.AuthUserDeleteResponse\"\x00\x12q\n\x12UserChangePassword\x12+.etcdserverpb.AuthUserChangePasswordRequest\x1a,.etcdserverpb.AuthUserChangePasswordResponse\"\x00\x12V\n\tUserGrant\x12\".etcdserverpb.AuthUserGrantRequest\x1a#.etcdserverpb.AuthUserGrantResponse\"\x00\x12Y\n\nUserRevoke\x12#.etcdserverpb.AuthUserRevokeRequest\x1a$.etcdserverpb.AuthUserRevokeResponse\"\x00\x12P\n\x07RoleAdd\x12 .etcdserverpb.AuthRoleAddRequest\x1a!.etcdserverpb.AuthRoleAddResponse\"\x00\x12P\n\x07RoleGet\x12 .etcdserverpb.AuthRoleGetRequest\x1a!.etcdserverpb.AuthRoleGetResponse\"\x00\x12Y\n\nRoleDelete\x12#.etcdserverpb.AuthRoleDeleteRequest\x1a$.etcdserverpb.AuthRoleDeleteResponse\"\x00\x12V\n\tRoleGrant\x12\".etcdserverpb.AuthRoleGrantRequest\x1a#.etcdserverpb.AuthRoleGrantResponse\"\x00\x12Y\n\nRoleRevoke\x12#.etcdserverpb.AuthRoleRevokeRequest\x1a$.etcdserverpb.AuthRoleRevokeResponse\"\x00\x42\x08\xc8\xe2\x1e\x01\xd0\xe2\x1e\x01\x62\x06proto3')
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,etcd_dot_storage_dot_storagepb_dot_kv__pb2.DESCRIPTOR,etcd_dot_auth_dot_authpb_dot_auth__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_ALARMTYPE = _descriptor.EnumDescriptor(
  name='AlarmType',
  full_name='etcdserverpb.AlarmType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOSPACE', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5903,
  serialized_end=5937,
)
_sym_db.RegisterEnumDescriptor(_ALARMTYPE)

AlarmType = enum_type_wrapper.EnumTypeWrapper(_ALARMTYPE)
NONE = 0
NOSPACE = 1


_RANGEREQUEST_SORTORDER = _descriptor.EnumDescriptor(
  name='SortOrder',
  full_name='etcdserverpb.RangeRequest.SortOrder',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASCEND', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESCEND', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=456,
  serialized_end=502,
)
_sym_db.RegisterEnumDescriptor(_RANGEREQUEST_SORTORDER)

_RANGEREQUEST_SORTTARGET = _descriptor.EnumDescriptor(
  name='SortTarget',
  full_name='etcdserverpb.RangeRequest.SortTarget',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KEY', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERSION', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOD', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALUE', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=504,
  serialized_end=570,
)
_sym_db.RegisterEnumDescriptor(_RANGEREQUEST_SORTTARGET)

_COMPARE_COMPARERESULT = _descriptor.EnumDescriptor(
  name='CompareResult',
  full_name='etcdserverpb.Compare.CompareResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1559,
  serialized_end=1608,
)
_sym_db.RegisterEnumDescriptor(_COMPARE_COMPARERESULT)

_COMPARE_COMPARETARGET = _descriptor.EnumDescriptor(
  name='CompareTarget',
  full_name='etcdserverpb.Compare.CompareTarget',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VERSION', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOD', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALUE', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1610,
  serialized_end=1670,
)
_sym_db.RegisterEnumDescriptor(_COMPARE_COMPARETARGET)

_ALARMREQUEST_ALARMACTION = _descriptor.EnumDescriptor(
  name='AlarmAction',
  full_name='etcdserverpb.AlarmRequest.AlarmAction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GET', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTIVATE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEACTIVATE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3959,
  serialized_end=4011,
)
_sym_db.RegisterEnumDescriptor(_ALARMREQUEST_ALARMACTION)


_RESPONSEHEADER = _descriptor.Descriptor(
  name='ResponseHeader',
  full_name='etcdserverpb.ResponseHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='etcdserverpb.ResponseHeader.cluster_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_id', full_name='etcdserverpb.ResponseHeader.member_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='revision', full_name='etcdserverpb.ResponseHeader.revision', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raft_term', full_name='etcdserverpb.ResponseHeader.raft_term', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=232,
)


_RANGEREQUEST = _descriptor.Descriptor(
  name='RangeRequest',
  full_name='etcdserverpb.RangeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='etcdserverpb.RangeRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='range_end', full_name='etcdserverpb.RangeRequest.range_end', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='limit', full_name='etcdserverpb.RangeRequest.limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='revision', full_name='etcdserverpb.RangeRequest.revision', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sort_order', full_name='etcdserverpb.RangeRequest.sort_order', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sort_target', full_name='etcdserverpb.RangeRequest.sort_target', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='serializable', full_name='etcdserverpb.RangeRequest.serializable', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RANGEREQUEST_SORTORDER,
    _RANGEREQUEST_SORTTARGET,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=570,
)


_RANGERESPONSE = _descriptor.Descriptor(
  name='RangeResponse',
  full_name='etcdserverpb.RangeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.RangeResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kvs', full_name='etcdserverpb.RangeResponse.kvs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='more', full_name='etcdserverpb.RangeResponse.more', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=572,
  serialized_end=681,
)


_PUTREQUEST = _descriptor.Descriptor(
  name='PutRequest',
  full_name='etcdserverpb.PutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='etcdserverpb.PutRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='etcdserverpb.PutRequest.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lease', full_name='etcdserverpb.PutRequest.lease', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=738,
)


_PUTRESPONSE = _descriptor.Descriptor(
  name='PutResponse',
  full_name='etcdserverpb.PutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.PutResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=740,
  serialized_end=799,
)


_DELETERANGEREQUEST = _descriptor.Descriptor(
  name='DeleteRangeRequest',
  full_name='etcdserverpb.DeleteRangeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='etcdserverpb.DeleteRangeRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='range_end', full_name='etcdserverpb.DeleteRangeRequest.range_end', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=801,
  serialized_end=853,
)


_DELETERANGERESPONSE = _descriptor.Descriptor(
  name='DeleteRangeResponse',
  full_name='etcdserverpb.DeleteRangeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.DeleteRangeResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='etcdserverpb.DeleteRangeResponse.deleted', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=939,
)


_REQUESTUNION = _descriptor.Descriptor(
  name='RequestUnion',
  full_name='etcdserverpb.RequestUnion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_range', full_name='etcdserverpb.RequestUnion.request_range', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='request_put', full_name='etcdserverpb.RequestUnion.request_put', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='request_delete_range', full_name='etcdserverpb.RequestUnion.request_delete_range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='etcdserverpb.RequestUnion.request',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=942,
  serialized_end=1135,
)


_RESPONSEUNION = _descriptor.Descriptor(
  name='ResponseUnion',
  full_name='etcdserverpb.ResponseUnion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_range', full_name='etcdserverpb.ResponseUnion.response_range', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='response_put', full_name='etcdserverpb.ResponseUnion.response_put', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='response_delete_range', full_name='etcdserverpb.ResponseUnion.response_delete_range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='etcdserverpb.ResponseUnion.response',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1138,
  serialized_end=1339,
)


_COMPARE = _descriptor.Descriptor(
  name='Compare',
  full_name='etcdserverpb.Compare',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='etcdserverpb.Compare.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target', full_name='etcdserverpb.Compare.target', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key', full_name='etcdserverpb.Compare.key', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='etcdserverpb.Compare.version', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='create_revision', full_name='etcdserverpb.Compare.create_revision', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mod_revision', full_name='etcdserverpb.Compare.mod_revision', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='etcdserverpb.Compare.value', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMPARE_COMPARERESULT,
    _COMPARE_COMPARETARGET,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target_union', full_name='etcdserverpb.Compare.target_union',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1342,
  serialized_end=1686,
)


_TXNREQUEST = _descriptor.Descriptor(
  name='TxnRequest',
  full_name='etcdserverpb.TxnRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='compare', full_name='etcdserverpb.TxnRequest.compare', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='success', full_name='etcdserverpb.TxnRequest.success', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='failure', full_name='etcdserverpb.TxnRequest.failure', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1689,
  serialized_end=1831,
)


_TXNRESPONSE = _descriptor.Descriptor(
  name='TxnResponse',
  full_name='etcdserverpb.TxnResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.TxnResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='succeeded', full_name='etcdserverpb.TxnResponse.succeeded', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='responses', full_name='etcdserverpb.TxnResponse.responses', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1833,
  serialized_end=1959,
)


_COMPACTIONREQUEST = _descriptor.Descriptor(
  name='CompactionRequest',
  full_name='etcdserverpb.CompactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='revision', full_name='etcdserverpb.CompactionRequest.revision', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='physical', full_name='etcdserverpb.CompactionRequest.physical', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1961,
  serialized_end=2016,
)


_COMPACTIONRESPONSE = _descriptor.Descriptor(
  name='CompactionResponse',
  full_name='etcdserverpb.CompactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.CompactionResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2018,
  serialized_end=2084,
)


_HASHREQUEST = _descriptor.Descriptor(
  name='HashRequest',
  full_name='etcdserverpb.HashRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2086,
  serialized_end=2099,
)


_HASHRESPONSE = _descriptor.Descriptor(
  name='HashResponse',
  full_name='etcdserverpb.HashResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.HashResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hash', full_name='etcdserverpb.HashResponse.hash', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2101,
  serialized_end=2175,
)


_SNAPSHOTREQUEST = _descriptor.Descriptor(
  name='SnapshotRequest',
  full_name='etcdserverpb.SnapshotRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2177,
  serialized_end=2194,
)


_SNAPSHOTRESPONSE = _descriptor.Descriptor(
  name='SnapshotResponse',
  full_name='etcdserverpb.SnapshotResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.SnapshotResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remaining_bytes', full_name='etcdserverpb.SnapshotResponse.remaining_bytes', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blob', full_name='etcdserverpb.SnapshotResponse.blob', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2196,
  serialized_end=2299,
)


_WATCHREQUEST = _descriptor.Descriptor(
  name='WatchRequest',
  full_name='etcdserverpb.WatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create_request', full_name='etcdserverpb.WatchRequest.create_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cancel_request', full_name='etcdserverpb.WatchRequest.cancel_request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request_union', full_name='etcdserverpb.WatchRequest.request_union',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2302,
  serialized_end=2453,
)


_WATCHCREATEREQUEST = _descriptor.Descriptor(
  name='WatchCreateRequest',
  full_name='etcdserverpb.WatchCreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='etcdserverpb.WatchCreateRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='range_end', full_name='etcdserverpb.WatchCreateRequest.range_end', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_revision', full_name='etcdserverpb.WatchCreateRequest.start_revision', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='progress_notify', full_name='etcdserverpb.WatchCreateRequest.progress_notify', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2455,
  serialized_end=2556,
)


_WATCHCANCELREQUEST = _descriptor.Descriptor(
  name='WatchCancelRequest',
  full_name='etcdserverpb.WatchCancelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='watch_id', full_name='etcdserverpb.WatchCancelRequest.watch_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2558,
  serialized_end=2596,
)


_WATCHRESPONSE = _descriptor.Descriptor(
  name='WatchResponse',
  full_name='etcdserverpb.WatchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.WatchResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='watch_id', full_name='etcdserverpb.WatchResponse.watch_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created', full_name='etcdserverpb.WatchResponse.created', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='canceled', full_name='etcdserverpb.WatchResponse.canceled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='compact_revision', full_name='etcdserverpb.WatchResponse.compact_revision', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='events', full_name='etcdserverpb.WatchResponse.events', index=5,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2599,
  serialized_end=2773,
)


_LEASEGRANTREQUEST = _descriptor.Descriptor(
  name='LeaseGrantRequest',
  full_name='etcdserverpb.LeaseGrantRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='TTL', full_name='etcdserverpb.LeaseGrantRequest.TTL', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ID', full_name='etcdserverpb.LeaseGrantRequest.ID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2775,
  serialized_end=2819,
)


_LEASEGRANTRESPONSE = _descriptor.Descriptor(
  name='LeaseGrantResponse',
  full_name='etcdserverpb.LeaseGrantResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.LeaseGrantResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ID', full_name='etcdserverpb.LeaseGrantResponse.ID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='TTL', full_name='etcdserverpb.LeaseGrantResponse.TTL', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='etcdserverpb.LeaseGrantResponse.error', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2821,
  serialized_end=2927,
)


_LEASEREVOKEREQUEST = _descriptor.Descriptor(
  name='LeaseRevokeRequest',
  full_name='etcdserverpb.LeaseRevokeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='etcdserverpb.LeaseRevokeRequest.ID', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2929,
  serialized_end=2961,
)


_LEASEREVOKERESPONSE = _descriptor.Descriptor(
  name='LeaseRevokeResponse',
  full_name='etcdserverpb.LeaseRevokeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.LeaseRevokeResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2963,
  serialized_end=3030,
)


_LEASEKEEPALIVEREQUEST = _descriptor.Descriptor(
  name='LeaseKeepAliveRequest',
  full_name='etcdserverpb.LeaseKeepAliveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='etcdserverpb.LeaseKeepAliveRequest.ID', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3032,
  serialized_end=3067,
)


_LEASEKEEPALIVERESPONSE = _descriptor.Descriptor(
  name='LeaseKeepAliveResponse',
  full_name='etcdserverpb.LeaseKeepAliveResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.LeaseKeepAliveResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ID', full_name='etcdserverpb.LeaseKeepAliveResponse.ID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='TTL', full_name='etcdserverpb.LeaseKeepAliveResponse.TTL', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3069,
  serialized_end=3164,
)


_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='etcdserverpb.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='etcdserverpb.Member.ID', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='etcdserverpb.Member.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='peerURLs', full_name='etcdserverpb.Member.peerURLs', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clientURLs', full_name='etcdserverpb.Member.clientURLs', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3166,
  serialized_end=3238,
)


_MEMBERADDREQUEST = _descriptor.Descriptor(
  name='MemberAddRequest',
  full_name='etcdserverpb.MemberAddRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peerURLs', full_name='etcdserverpb.MemberAddRequest.peerURLs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3240,
  serialized_end=3276,
)


_MEMBERADDRESPONSE = _descriptor.Descriptor(
  name='MemberAddResponse',
  full_name='etcdserverpb.MemberAddResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.MemberAddResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member', full_name='etcdserverpb.MemberAddResponse.member', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3278,
  serialized_end=3381,
)


_MEMBERREMOVEREQUEST = _descriptor.Descriptor(
  name='MemberRemoveRequest',
  full_name='etcdserverpb.MemberRemoveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='etcdserverpb.MemberRemoveRequest.ID', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3383,
  serialized_end=3416,
)


_MEMBERREMOVERESPONSE = _descriptor.Descriptor(
  name='MemberRemoveResponse',
  full_name='etcdserverpb.MemberRemoveResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.MemberRemoveResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3418,
  serialized_end=3486,
)


_MEMBERUPDATEREQUEST = _descriptor.Descriptor(
  name='MemberUpdateRequest',
  full_name='etcdserverpb.MemberUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='etcdserverpb.MemberUpdateRequest.ID', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='peerURLs', full_name='etcdserverpb.MemberUpdateRequest.peerURLs', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3488,
  serialized_end=3539,
)


_MEMBERUPDATERESPONSE = _descriptor.Descriptor(
  name='MemberUpdateResponse',
  full_name='etcdserverpb.MemberUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.MemberUpdateResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3541,
  serialized_end=3609,
)


_MEMBERLISTREQUEST = _descriptor.Descriptor(
  name='MemberListRequest',
  full_name='etcdserverpb.MemberListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3611,
  serialized_end=3630,
)


_MEMBERLISTRESPONSE = _descriptor.Descriptor(
  name='MemberListResponse',
  full_name='etcdserverpb.MemberListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.MemberListResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='members', full_name='etcdserverpb.MemberListResponse.members', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3632,
  serialized_end=3737,
)


_DEFRAGMENTREQUEST = _descriptor.Descriptor(
  name='DefragmentRequest',
  full_name='etcdserverpb.DefragmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3739,
  serialized_end=3758,
)


_DEFRAGMENTRESPONSE = _descriptor.Descriptor(
  name='DefragmentResponse',
  full_name='etcdserverpb.DefragmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.DefragmentResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3760,
  serialized_end=3826,
)


_ALARMREQUEST = _descriptor.Descriptor(
  name='AlarmRequest',
  full_name='etcdserverpb.AlarmRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='etcdserverpb.AlarmRequest.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='memberID', full_name='etcdserverpb.AlarmRequest.memberID', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='alarm', full_name='etcdserverpb.AlarmRequest.alarm', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALARMREQUEST_ALARMACTION,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3829,
  serialized_end=4011,
)


_ALARMMEMBER = _descriptor.Descriptor(
  name='AlarmMember',
  full_name='etcdserverpb.AlarmMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='memberID', full_name='etcdserverpb.AlarmMember.memberID', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='alarm', full_name='etcdserverpb.AlarmMember.alarm', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4013,
  serialized_end=4084,
)


_ALARMRESPONSE = _descriptor.Descriptor(
  name='AlarmResponse',
  full_name='etcdserverpb.AlarmResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AlarmResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='alarms', full_name='etcdserverpb.AlarmResponse.alarms', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4086,
  serialized_end=4190,
)


_STATUSREQUEST = _descriptor.Descriptor(
  name='StatusRequest',
  full_name='etcdserverpb.StatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4192,
  serialized_end=4207,
)


_STATUSRESPONSE = _descriptor.Descriptor(
  name='StatusResponse',
  full_name='etcdserverpb.StatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.StatusResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='etcdserverpb.StatusResponse.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dbSize', full_name='etcdserverpb.StatusResponse.dbSize', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leader', full_name='etcdserverpb.StatusResponse.leader', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raftIndex', full_name='etcdserverpb.StatusResponse.raftIndex', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raftTerm', full_name='etcdserverpb.StatusResponse.raftTerm', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4210,
  serialized_end=4358,
)


_AUTHENABLEREQUEST = _descriptor.Descriptor(
  name='AuthEnableRequest',
  full_name='etcdserverpb.AuthEnableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4360,
  serialized_end=4379,
)


_AUTHDISABLEREQUEST = _descriptor.Descriptor(
  name='AuthDisableRequest',
  full_name='etcdserverpb.AuthDisableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4381,
  serialized_end=4401,
)


_AUTHENTICATEREQUEST = _descriptor.Descriptor(
  name='AuthenticateRequest',
  full_name='etcdserverpb.AuthenticateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='etcdserverpb.AuthenticateRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='etcdserverpb.AuthenticateRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4403,
  serialized_end=4456,
)


_AUTHUSERADDREQUEST = _descriptor.Descriptor(
  name='AuthUserAddRequest',
  full_name='etcdserverpb.AuthUserAddRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='etcdserverpb.AuthUserAddRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='etcdserverpb.AuthUserAddRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4458,
  serialized_end=4510,
)


_AUTHUSERGETREQUEST = _descriptor.Descriptor(
  name='AuthUserGetRequest',
  full_name='etcdserverpb.AuthUserGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4512,
  serialized_end=4532,
)


_AUTHUSERDELETEREQUEST = _descriptor.Descriptor(
  name='AuthUserDeleteRequest',
  full_name='etcdserverpb.AuthUserDeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='etcdserverpb.AuthUserDeleteRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4534,
  serialized_end=4571,
)


_AUTHUSERCHANGEPASSWORDREQUEST = _descriptor.Descriptor(
  name='AuthUserChangePasswordRequest',
  full_name='etcdserverpb.AuthUserChangePasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='etcdserverpb.AuthUserChangePasswordRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='etcdserverpb.AuthUserChangePasswordRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4573,
  serialized_end=4636,
)


_AUTHUSERGRANTREQUEST = _descriptor.Descriptor(
  name='AuthUserGrantRequest',
  full_name='etcdserverpb.AuthUserGrantRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='etcdserverpb.AuthUserGrantRequest.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='etcdserverpb.AuthUserGrantRequest.role', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4638,
  serialized_end=4688,
)


_AUTHUSERREVOKEREQUEST = _descriptor.Descriptor(
  name='AuthUserRevokeRequest',
  full_name='etcdserverpb.AuthUserRevokeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4690,
  serialized_end=4713,
)


_AUTHROLEADDREQUEST = _descriptor.Descriptor(
  name='AuthRoleAddRequest',
  full_name='etcdserverpb.AuthRoleAddRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='etcdserverpb.AuthRoleAddRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4715,
  serialized_end=4749,
)


_AUTHROLEGETREQUEST = _descriptor.Descriptor(
  name='AuthRoleGetRequest',
  full_name='etcdserverpb.AuthRoleGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4751,
  serialized_end=4771,
)


_AUTHROLEDELETEREQUEST = _descriptor.Descriptor(
  name='AuthRoleDeleteRequest',
  full_name='etcdserverpb.AuthRoleDeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4773,
  serialized_end=4796,
)


_AUTHROLEGRANTREQUEST = _descriptor.Descriptor(
  name='AuthRoleGrantRequest',
  full_name='etcdserverpb.AuthRoleGrantRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='etcdserverpb.AuthRoleGrantRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='perm', full_name='etcdserverpb.AuthRoleGrantRequest.perm', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4798,
  serialized_end=4868,
)


_AUTHROLEREVOKEREQUEST = _descriptor.Descriptor(
  name='AuthRoleRevokeRequest',
  full_name='etcdserverpb.AuthRoleRevokeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4870,
  serialized_end=4893,
)


_AUTHENABLERESPONSE = _descriptor.Descriptor(
  name='AuthEnableResponse',
  full_name='etcdserverpb.AuthEnableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AuthEnableResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4895,
  serialized_end=4961,
)


_AUTHDISABLERESPONSE = _descriptor.Descriptor(
  name='AuthDisableResponse',
  full_name='etcdserverpb.AuthDisableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AuthDisableResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4963,
  serialized_end=5030,
)


_AUTHENTICATERESPONSE = _descriptor.Descriptor(
  name='AuthenticateResponse',
  full_name='etcdserverpb.AuthenticateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AuthenticateResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='etcdserverpb.AuthenticateResponse.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5032,
  serialized_end=5115,
)


_AUTHUSERADDRESPONSE = _descriptor.Descriptor(
  name='AuthUserAddResponse',
  full_name='etcdserverpb.AuthUserAddResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AuthUserAddResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5117,
  serialized_end=5184,
)


_AUTHUSERGETRESPONSE = _descriptor.Descriptor(
  name='AuthUserGetResponse',
  full_name='etcdserverpb.AuthUserGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AuthUserGetResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5186,
  serialized_end=5253,
)


_AUTHUSERDELETERESPONSE = _descriptor.Descriptor(
  name='AuthUserDeleteResponse',
  full_name='etcdserverpb.AuthUserDeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AuthUserDeleteResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5255,
  serialized_end=5325,
)


_AUTHUSERCHANGEPASSWORDRESPONSE = _descriptor.Descriptor(
  name='AuthUserChangePasswordResponse',
  full_name='etcdserverpb.AuthUserChangePasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AuthUserChangePasswordResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5327,
  serialized_end=5405,
)


_AUTHUSERGRANTRESPONSE = _descriptor.Descriptor(
  name='AuthUserGrantResponse',
  full_name='etcdserverpb.AuthUserGrantResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AuthUserGrantResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5407,
  serialized_end=5476,
)


_AUTHUSERREVOKERESPONSE = _descriptor.Descriptor(
  name='AuthUserRevokeResponse',
  full_name='etcdserverpb.AuthUserRevokeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AuthUserRevokeResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5478,
  serialized_end=5548,
)


_AUTHROLEADDRESPONSE = _descriptor.Descriptor(
  name='AuthRoleAddResponse',
  full_name='etcdserverpb.AuthRoleAddResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AuthRoleAddResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5550,
  serialized_end=5617,
)


_AUTHROLEGETRESPONSE = _descriptor.Descriptor(
  name='AuthRoleGetResponse',
  full_name='etcdserverpb.AuthRoleGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AuthRoleGetResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5619,
  serialized_end=5686,
)


_AUTHROLEDELETERESPONSE = _descriptor.Descriptor(
  name='AuthRoleDeleteResponse',
  full_name='etcdserverpb.AuthRoleDeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AuthRoleDeleteResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5688,
  serialized_end=5758,
)


_AUTHROLEGRANTRESPONSE = _descriptor.Descriptor(
  name='AuthRoleGrantResponse',
  full_name='etcdserverpb.AuthRoleGrantResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AuthRoleGrantResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5760,
  serialized_end=5829,
)


_AUTHROLEREVOKERESPONSE = _descriptor.Descriptor(
  name='AuthRoleRevokeResponse',
  full_name='etcdserverpb.AuthRoleRevokeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='etcdserverpb.AuthRoleRevokeResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5831,
  serialized_end=5901,
)

_RANGEREQUEST.fields_by_name['sort_order'].enum_type = _RANGEREQUEST_SORTORDER
_RANGEREQUEST.fields_by_name['sort_target'].enum_type = _RANGEREQUEST_SORTTARGET
_RANGEREQUEST_SORTORDER.containing_type = _RANGEREQUEST
_RANGEREQUEST_SORTTARGET.containing_type = _RANGEREQUEST
_RANGERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_RANGERESPONSE.fields_by_name['kvs'].message_type = etcd_dot_storage_dot_storagepb_dot_kv__pb2._KEYVALUE
_PUTRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_DELETERANGERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_REQUESTUNION.fields_by_name['request_range'].message_type = _RANGEREQUEST
_REQUESTUNION.fields_by_name['request_put'].message_type = _PUTREQUEST
_REQUESTUNION.fields_by_name['request_delete_range'].message_type = _DELETERANGEREQUEST
_REQUESTUNION.oneofs_by_name['request'].fields.append(
  _REQUESTUNION.fields_by_name['request_range'])
_REQUESTUNION.fields_by_name['request_range'].containing_oneof = _REQUESTUNION.oneofs_by_name['request']
_REQUESTUNION.oneofs_by_name['request'].fields.append(
  _REQUESTUNION.fields_by_name['request_put'])
_REQUESTUNION.fields_by_name['request_put'].containing_oneof = _REQUESTUNION.oneofs_by_name['request']
_REQUESTUNION.oneofs_by_name['request'].fields.append(
  _REQUESTUNION.fields_by_name['request_delete_range'])
_REQUESTUNION.fields_by_name['request_delete_range'].containing_oneof = _REQUESTUNION.oneofs_by_name['request']
_RESPONSEUNION.fields_by_name['response_range'].message_type = _RANGERESPONSE
_RESPONSEUNION.fields_by_name['response_put'].message_type = _PUTRESPONSE
_RESPONSEUNION.fields_by_name['response_delete_range'].message_type = _DELETERANGERESPONSE
_RESPONSEUNION.oneofs_by_name['response'].fields.append(
  _RESPONSEUNION.fields_by_name['response_range'])
_RESPONSEUNION.fields_by_name['response_range'].containing_oneof = _RESPONSEUNION.oneofs_by_name['response']
_RESPONSEUNION.oneofs_by_name['response'].fields.append(
  _RESPONSEUNION.fields_by_name['response_put'])
_RESPONSEUNION.fields_by_name['response_put'].containing_oneof = _RESPONSEUNION.oneofs_by_name['response']
_RESPONSEUNION.oneofs_by_name['response'].fields.append(
  _RESPONSEUNION.fields_by_name['response_delete_range'])
_RESPONSEUNION.fields_by_name['response_delete_range'].containing_oneof = _RESPONSEUNION.oneofs_by_name['response']
_COMPARE.fields_by_name['result'].enum_type = _COMPARE_COMPARERESULT
_COMPARE.fields_by_name['target'].enum_type = _COMPARE_COMPARETARGET
_COMPARE_COMPARERESULT.containing_type = _COMPARE
_COMPARE_COMPARETARGET.containing_type = _COMPARE
_COMPARE.oneofs_by_name['target_union'].fields.append(
  _COMPARE.fields_by_name['version'])
_COMPARE.fields_by_name['version'].containing_oneof = _COMPARE.oneofs_by_name['target_union']
_COMPARE.oneofs_by_name['target_union'].fields.append(
  _COMPARE.fields_by_name['create_revision'])
_COMPARE.fields_by_name['create_revision'].containing_oneof = _COMPARE.oneofs_by_name['target_union']
_COMPARE.oneofs_by_name['target_union'].fields.append(
  _COMPARE.fields_by_name['mod_revision'])
_COMPARE.fields_by_name['mod_revision'].containing_oneof = _COMPARE.oneofs_by_name['target_union']
_COMPARE.oneofs_by_name['target_union'].fields.append(
  _COMPARE.fields_by_name['value'])
_COMPARE.fields_by_name['value'].containing_oneof = _COMPARE.oneofs_by_name['target_union']
_TXNREQUEST.fields_by_name['compare'].message_type = _COMPARE
_TXNREQUEST.fields_by_name['success'].message_type = _REQUESTUNION
_TXNREQUEST.fields_by_name['failure'].message_type = _REQUESTUNION
_TXNRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_TXNRESPONSE.fields_by_name['responses'].message_type = _RESPONSEUNION
_COMPACTIONRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_HASHRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_SNAPSHOTRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_WATCHREQUEST.fields_by_name['create_request'].message_type = _WATCHCREATEREQUEST
_WATCHREQUEST.fields_by_name['cancel_request'].message_type = _WATCHCANCELREQUEST
_WATCHREQUEST.oneofs_by_name['request_union'].fields.append(
  _WATCHREQUEST.fields_by_name['create_request'])
_WATCHREQUEST.fields_by_name['create_request'].containing_oneof = _WATCHREQUEST.oneofs_by_name['request_union']
_WATCHREQUEST.oneofs_by_name['request_union'].fields.append(
  _WATCHREQUEST.fields_by_name['cancel_request'])
_WATCHREQUEST.fields_by_name['cancel_request'].containing_oneof = _WATCHREQUEST.oneofs_by_name['request_union']
_WATCHRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_WATCHRESPONSE.fields_by_name['events'].message_type = etcd_dot_storage_dot_storagepb_dot_kv__pb2._EVENT
_LEASEGRANTRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_LEASEREVOKERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_LEASEKEEPALIVERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_MEMBERADDRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_MEMBERADDRESPONSE.fields_by_name['member'].message_type = _MEMBER
_MEMBERREMOVERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_MEMBERUPDATERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_MEMBERLISTRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_MEMBERLISTRESPONSE.fields_by_name['members'].message_type = _MEMBER
_DEFRAGMENTRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_ALARMREQUEST.fields_by_name['action'].enum_type = _ALARMREQUEST_ALARMACTION
_ALARMREQUEST.fields_by_name['alarm'].enum_type = _ALARMTYPE
_ALARMREQUEST_ALARMACTION.containing_type = _ALARMREQUEST
_ALARMMEMBER.fields_by_name['alarm'].enum_type = _ALARMTYPE
_ALARMRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_ALARMRESPONSE.fields_by_name['alarms'].message_type = _ALARMMEMBER
_STATUSRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_AUTHROLEGRANTREQUEST.fields_by_name['perm'].message_type = etcd_dot_auth_dot_authpb_dot_auth__pb2._PERMISSION
_AUTHENABLERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_AUTHDISABLERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_AUTHENTICATERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_AUTHUSERADDRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_AUTHUSERGETRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_AUTHUSERDELETERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_AUTHUSERCHANGEPASSWORDRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_AUTHUSERGRANTRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_AUTHUSERREVOKERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_AUTHROLEADDRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_AUTHROLEGETRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_AUTHROLEDELETERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_AUTHROLEGRANTRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_AUTHROLEREVOKERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
DESCRIPTOR.message_types_by_name['ResponseHeader'] = _RESPONSEHEADER
DESCRIPTOR.message_types_by_name['RangeRequest'] = _RANGEREQUEST
DESCRIPTOR.message_types_by_name['RangeResponse'] = _RANGERESPONSE
DESCRIPTOR.message_types_by_name['PutRequest'] = _PUTREQUEST
DESCRIPTOR.message_types_by_name['PutResponse'] = _PUTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRangeRequest'] = _DELETERANGEREQUEST
DESCRIPTOR.message_types_by_name['DeleteRangeResponse'] = _DELETERANGERESPONSE
DESCRIPTOR.message_types_by_name['RequestUnion'] = _REQUESTUNION
DESCRIPTOR.message_types_by_name['ResponseUnion'] = _RESPONSEUNION
DESCRIPTOR.message_types_by_name['Compare'] = _COMPARE
DESCRIPTOR.message_types_by_name['TxnRequest'] = _TXNREQUEST
DESCRIPTOR.message_types_by_name['TxnResponse'] = _TXNRESPONSE
DESCRIPTOR.message_types_by_name['CompactionRequest'] = _COMPACTIONREQUEST
DESCRIPTOR.message_types_by_name['CompactionResponse'] = _COMPACTIONRESPONSE
DESCRIPTOR.message_types_by_name['HashRequest'] = _HASHREQUEST
DESCRIPTOR.message_types_by_name['HashResponse'] = _HASHRESPONSE
DESCRIPTOR.message_types_by_name['SnapshotRequest'] = _SNAPSHOTREQUEST
DESCRIPTOR.message_types_by_name['SnapshotResponse'] = _SNAPSHOTRESPONSE
DESCRIPTOR.message_types_by_name['WatchRequest'] = _WATCHREQUEST
DESCRIPTOR.message_types_by_name['WatchCreateRequest'] = _WATCHCREATEREQUEST
DESCRIPTOR.message_types_by_name['WatchCancelRequest'] = _WATCHCANCELREQUEST
DESCRIPTOR.message_types_by_name['WatchResponse'] = _WATCHRESPONSE
DESCRIPTOR.message_types_by_name['LeaseGrantRequest'] = _LEASEGRANTREQUEST
DESCRIPTOR.message_types_by_name['LeaseGrantResponse'] = _LEASEGRANTRESPONSE
DESCRIPTOR.message_types_by_name['LeaseRevokeRequest'] = _LEASEREVOKEREQUEST
DESCRIPTOR.message_types_by_name['LeaseRevokeResponse'] = _LEASEREVOKERESPONSE
DESCRIPTOR.message_types_by_name['LeaseKeepAliveRequest'] = _LEASEKEEPALIVEREQUEST
DESCRIPTOR.message_types_by_name['LeaseKeepAliveResponse'] = _LEASEKEEPALIVERESPONSE
DESCRIPTOR.message_types_by_name['Member'] = _MEMBER
DESCRIPTOR.message_types_by_name['MemberAddRequest'] = _MEMBERADDREQUEST
DESCRIPTOR.message_types_by_name['MemberAddResponse'] = _MEMBERADDRESPONSE
DESCRIPTOR.message_types_by_name['MemberRemoveRequest'] = _MEMBERREMOVEREQUEST
DESCRIPTOR.message_types_by_name['MemberRemoveResponse'] = _MEMBERREMOVERESPONSE
DESCRIPTOR.message_types_by_name['MemberUpdateRequest'] = _MEMBERUPDATEREQUEST
DESCRIPTOR.message_types_by_name['MemberUpdateResponse'] = _MEMBERUPDATERESPONSE
DESCRIPTOR.message_types_by_name['MemberListRequest'] = _MEMBERLISTREQUEST
DESCRIPTOR.message_types_by_name['MemberListResponse'] = _MEMBERLISTRESPONSE
DESCRIPTOR.message_types_by_name['DefragmentRequest'] = _DEFRAGMENTREQUEST
DESCRIPTOR.message_types_by_name['DefragmentResponse'] = _DEFRAGMENTRESPONSE
DESCRIPTOR.message_types_by_name['AlarmRequest'] = _ALARMREQUEST
DESCRIPTOR.message_types_by_name['AlarmMember'] = _ALARMMEMBER
DESCRIPTOR.message_types_by_name['AlarmResponse'] = _ALARMRESPONSE
DESCRIPTOR.message_types_by_name['StatusRequest'] = _STATUSREQUEST
DESCRIPTOR.message_types_by_name['StatusResponse'] = _STATUSRESPONSE
DESCRIPTOR.message_types_by_name['AuthEnableRequest'] = _AUTHENABLEREQUEST
DESCRIPTOR.message_types_by_name['AuthDisableRequest'] = _AUTHDISABLEREQUEST
DESCRIPTOR.message_types_by_name['AuthenticateRequest'] = _AUTHENTICATEREQUEST
DESCRIPTOR.message_types_by_name['AuthUserAddRequest'] = _AUTHUSERADDREQUEST
DESCRIPTOR.message_types_by_name['AuthUserGetRequest'] = _AUTHUSERGETREQUEST
DESCRIPTOR.message_types_by_name['AuthUserDeleteRequest'] = _AUTHUSERDELETEREQUEST
DESCRIPTOR.message_types_by_name['AuthUserChangePasswordRequest'] = _AUTHUSERCHANGEPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['AuthUserGrantRequest'] = _AUTHUSERGRANTREQUEST
DESCRIPTOR.message_types_by_name['AuthUserRevokeRequest'] = _AUTHUSERREVOKEREQUEST
DESCRIPTOR.message_types_by_name['AuthRoleAddRequest'] = _AUTHROLEADDREQUEST
DESCRIPTOR.message_types_by_name['AuthRoleGetRequest'] = _AUTHROLEGETREQUEST
DESCRIPTOR.message_types_by_name['AuthRoleDeleteRequest'] = _AUTHROLEDELETEREQUEST
DESCRIPTOR.message_types_by_name['AuthRoleGrantRequest'] = _AUTHROLEGRANTREQUEST
DESCRIPTOR.message_types_by_name['AuthRoleRevokeRequest'] = _AUTHROLEREVOKEREQUEST
DESCRIPTOR.message_types_by_name['AuthEnableResponse'] = _AUTHENABLERESPONSE
DESCRIPTOR.message_types_by_name['AuthDisableResponse'] = _AUTHDISABLERESPONSE
DESCRIPTOR.message_types_by_name['AuthenticateResponse'] = _AUTHENTICATERESPONSE
DESCRIPTOR.message_types_by_name['AuthUserAddResponse'] = _AUTHUSERADDRESPONSE
DESCRIPTOR.message_types_by_name['AuthUserGetResponse'] = _AUTHUSERGETRESPONSE
DESCRIPTOR.message_types_by_name['AuthUserDeleteResponse'] = _AUTHUSERDELETERESPONSE
DESCRIPTOR.message_types_by_name['AuthUserChangePasswordResponse'] = _AUTHUSERCHANGEPASSWORDRESPONSE
DESCRIPTOR.message_types_by_name['AuthUserGrantResponse'] = _AUTHUSERGRANTRESPONSE
DESCRIPTOR.message_types_by_name['AuthUserRevokeResponse'] = _AUTHUSERREVOKERESPONSE
DESCRIPTOR.message_types_by_name['AuthRoleAddResponse'] = _AUTHROLEADDRESPONSE
DESCRIPTOR.message_types_by_name['AuthRoleGetResponse'] = _AUTHROLEGETRESPONSE
DESCRIPTOR.message_types_by_name['AuthRoleDeleteResponse'] = _AUTHROLEDELETERESPONSE
DESCRIPTOR.message_types_by_name['AuthRoleGrantResponse'] = _AUTHROLEGRANTRESPONSE
DESCRIPTOR.message_types_by_name['AuthRoleRevokeResponse'] = _AUTHROLEREVOKERESPONSE
DESCRIPTOR.enum_types_by_name['AlarmType'] = _ALARMTYPE

ResponseHeader = _reflection.GeneratedProtocolMessageType('ResponseHeader', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEHEADER,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.ResponseHeader)
  ))
_sym_db.RegisterMessage(ResponseHeader)

RangeRequest = _reflection.GeneratedProtocolMessageType('RangeRequest', (_message.Message,), dict(
  DESCRIPTOR = _RANGEREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.RangeRequest)
  ))
_sym_db.RegisterMessage(RangeRequest)

RangeResponse = _reflection.GeneratedProtocolMessageType('RangeResponse', (_message.Message,), dict(
  DESCRIPTOR = _RANGERESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.RangeResponse)
  ))
_sym_db.RegisterMessage(RangeResponse)

PutRequest = _reflection.GeneratedProtocolMessageType('PutRequest', (_message.Message,), dict(
  DESCRIPTOR = _PUTREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.PutRequest)
  ))
_sym_db.RegisterMessage(PutRequest)

PutResponse = _reflection.GeneratedProtocolMessageType('PutResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUTRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.PutResponse)
  ))
_sym_db.RegisterMessage(PutResponse)

DeleteRangeRequest = _reflection.GeneratedProtocolMessageType('DeleteRangeRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETERANGEREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.DeleteRangeRequest)
  ))
_sym_db.RegisterMessage(DeleteRangeRequest)

DeleteRangeResponse = _reflection.GeneratedProtocolMessageType('DeleteRangeResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETERANGERESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.DeleteRangeResponse)
  ))
_sym_db.RegisterMessage(DeleteRangeResponse)

RequestUnion = _reflection.GeneratedProtocolMessageType('RequestUnion', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTUNION,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.RequestUnion)
  ))
_sym_db.RegisterMessage(RequestUnion)

ResponseUnion = _reflection.GeneratedProtocolMessageType('ResponseUnion', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEUNION,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.ResponseUnion)
  ))
_sym_db.RegisterMessage(ResponseUnion)

Compare = _reflection.GeneratedProtocolMessageType('Compare', (_message.Message,), dict(
  DESCRIPTOR = _COMPARE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.Compare)
  ))
_sym_db.RegisterMessage(Compare)

TxnRequest = _reflection.GeneratedProtocolMessageType('TxnRequest', (_message.Message,), dict(
  DESCRIPTOR = _TXNREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.TxnRequest)
  ))
_sym_db.RegisterMessage(TxnRequest)

TxnResponse = _reflection.GeneratedProtocolMessageType('TxnResponse', (_message.Message,), dict(
  DESCRIPTOR = _TXNRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.TxnResponse)
  ))
_sym_db.RegisterMessage(TxnResponse)

CompactionRequest = _reflection.GeneratedProtocolMessageType('CompactionRequest', (_message.Message,), dict(
  DESCRIPTOR = _COMPACTIONREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.CompactionRequest)
  ))
_sym_db.RegisterMessage(CompactionRequest)

CompactionResponse = _reflection.GeneratedProtocolMessageType('CompactionResponse', (_message.Message,), dict(
  DESCRIPTOR = _COMPACTIONRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.CompactionResponse)
  ))
_sym_db.RegisterMessage(CompactionResponse)

HashRequest = _reflection.GeneratedProtocolMessageType('HashRequest', (_message.Message,), dict(
  DESCRIPTOR = _HASHREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.HashRequest)
  ))
_sym_db.RegisterMessage(HashRequest)

HashResponse = _reflection.GeneratedProtocolMessageType('HashResponse', (_message.Message,), dict(
  DESCRIPTOR = _HASHRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.HashResponse)
  ))
_sym_db.RegisterMessage(HashResponse)

SnapshotRequest = _reflection.GeneratedProtocolMessageType('SnapshotRequest', (_message.Message,), dict(
  DESCRIPTOR = _SNAPSHOTREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.SnapshotRequest)
  ))
_sym_db.RegisterMessage(SnapshotRequest)

SnapshotResponse = _reflection.GeneratedProtocolMessageType('SnapshotResponse', (_message.Message,), dict(
  DESCRIPTOR = _SNAPSHOTRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.SnapshotResponse)
  ))
_sym_db.RegisterMessage(SnapshotResponse)

WatchRequest = _reflection.GeneratedProtocolMessageType('WatchRequest', (_message.Message,), dict(
  DESCRIPTOR = _WATCHREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.WatchRequest)
  ))
_sym_db.RegisterMessage(WatchRequest)

WatchCreateRequest = _reflection.GeneratedProtocolMessageType('WatchCreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _WATCHCREATEREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.WatchCreateRequest)
  ))
_sym_db.RegisterMessage(WatchCreateRequest)

WatchCancelRequest = _reflection.GeneratedProtocolMessageType('WatchCancelRequest', (_message.Message,), dict(
  DESCRIPTOR = _WATCHCANCELREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.WatchCancelRequest)
  ))
_sym_db.RegisterMessage(WatchCancelRequest)

WatchResponse = _reflection.GeneratedProtocolMessageType('WatchResponse', (_message.Message,), dict(
  DESCRIPTOR = _WATCHRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.WatchResponse)
  ))
_sym_db.RegisterMessage(WatchResponse)

LeaseGrantRequest = _reflection.GeneratedProtocolMessageType('LeaseGrantRequest', (_message.Message,), dict(
  DESCRIPTOR = _LEASEGRANTREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseGrantRequest)
  ))
_sym_db.RegisterMessage(LeaseGrantRequest)

LeaseGrantResponse = _reflection.GeneratedProtocolMessageType('LeaseGrantResponse', (_message.Message,), dict(
  DESCRIPTOR = _LEASEGRANTRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseGrantResponse)
  ))
_sym_db.RegisterMessage(LeaseGrantResponse)

LeaseRevokeRequest = _reflection.GeneratedProtocolMessageType('LeaseRevokeRequest', (_message.Message,), dict(
  DESCRIPTOR = _LEASEREVOKEREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseRevokeRequest)
  ))
_sym_db.RegisterMessage(LeaseRevokeRequest)

LeaseRevokeResponse = _reflection.GeneratedProtocolMessageType('LeaseRevokeResponse', (_message.Message,), dict(
  DESCRIPTOR = _LEASEREVOKERESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseRevokeResponse)
  ))
_sym_db.RegisterMessage(LeaseRevokeResponse)

LeaseKeepAliveRequest = _reflection.GeneratedProtocolMessageType('LeaseKeepAliveRequest', (_message.Message,), dict(
  DESCRIPTOR = _LEASEKEEPALIVEREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseKeepAliveRequest)
  ))
_sym_db.RegisterMessage(LeaseKeepAliveRequest)

LeaseKeepAliveResponse = _reflection.GeneratedProtocolMessageType('LeaseKeepAliveResponse', (_message.Message,), dict(
  DESCRIPTOR = _LEASEKEEPALIVERESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseKeepAliveResponse)
  ))
_sym_db.RegisterMessage(LeaseKeepAliveResponse)

Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
  DESCRIPTOR = _MEMBER,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.Member)
  ))
_sym_db.RegisterMessage(Member)

MemberAddRequest = _reflection.GeneratedProtocolMessageType('MemberAddRequest', (_message.Message,), dict(
  DESCRIPTOR = _MEMBERADDREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberAddRequest)
  ))
_sym_db.RegisterMessage(MemberAddRequest)

MemberAddResponse = _reflection.GeneratedProtocolMessageType('MemberAddResponse', (_message.Message,), dict(
  DESCRIPTOR = _MEMBERADDRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberAddResponse)
  ))
_sym_db.RegisterMessage(MemberAddResponse)

MemberRemoveRequest = _reflection.GeneratedProtocolMessageType('MemberRemoveRequest', (_message.Message,), dict(
  DESCRIPTOR = _MEMBERREMOVEREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberRemoveRequest)
  ))
_sym_db.RegisterMessage(MemberRemoveRequest)

MemberRemoveResponse = _reflection.GeneratedProtocolMessageType('MemberRemoveResponse', (_message.Message,), dict(
  DESCRIPTOR = _MEMBERREMOVERESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberRemoveResponse)
  ))
_sym_db.RegisterMessage(MemberRemoveResponse)

MemberUpdateRequest = _reflection.GeneratedProtocolMessageType('MemberUpdateRequest', (_message.Message,), dict(
  DESCRIPTOR = _MEMBERUPDATEREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberUpdateRequest)
  ))
_sym_db.RegisterMessage(MemberUpdateRequest)

MemberUpdateResponse = _reflection.GeneratedProtocolMessageType('MemberUpdateResponse', (_message.Message,), dict(
  DESCRIPTOR = _MEMBERUPDATERESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberUpdateResponse)
  ))
_sym_db.RegisterMessage(MemberUpdateResponse)

MemberListRequest = _reflection.GeneratedProtocolMessageType('MemberListRequest', (_message.Message,), dict(
  DESCRIPTOR = _MEMBERLISTREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberListRequest)
  ))
_sym_db.RegisterMessage(MemberListRequest)

MemberListResponse = _reflection.GeneratedProtocolMessageType('MemberListResponse', (_message.Message,), dict(
  DESCRIPTOR = _MEMBERLISTRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberListResponse)
  ))
_sym_db.RegisterMessage(MemberListResponse)

DefragmentRequest = _reflection.GeneratedProtocolMessageType('DefragmentRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEFRAGMENTREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.DefragmentRequest)
  ))
_sym_db.RegisterMessage(DefragmentRequest)

DefragmentResponse = _reflection.GeneratedProtocolMessageType('DefragmentResponse', (_message.Message,), dict(
  DESCRIPTOR = _DEFRAGMENTRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.DefragmentResponse)
  ))
_sym_db.RegisterMessage(DefragmentResponse)

AlarmRequest = _reflection.GeneratedProtocolMessageType('AlarmRequest', (_message.Message,), dict(
  DESCRIPTOR = _ALARMREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AlarmRequest)
  ))
_sym_db.RegisterMessage(AlarmRequest)

AlarmMember = _reflection.GeneratedProtocolMessageType('AlarmMember', (_message.Message,), dict(
  DESCRIPTOR = _ALARMMEMBER,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AlarmMember)
  ))
_sym_db.RegisterMessage(AlarmMember)

AlarmResponse = _reflection.GeneratedProtocolMessageType('AlarmResponse', (_message.Message,), dict(
  DESCRIPTOR = _ALARMRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AlarmResponse)
  ))
_sym_db.RegisterMessage(AlarmResponse)

StatusRequest = _reflection.GeneratedProtocolMessageType('StatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _STATUSREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.StatusRequest)
  ))
_sym_db.RegisterMessage(StatusRequest)

StatusResponse = _reflection.GeneratedProtocolMessageType('StatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _STATUSRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.StatusResponse)
  ))
_sym_db.RegisterMessage(StatusResponse)

AuthEnableRequest = _reflection.GeneratedProtocolMessageType('AuthEnableRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHENABLEREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthEnableRequest)
  ))
_sym_db.RegisterMessage(AuthEnableRequest)

AuthDisableRequest = _reflection.GeneratedProtocolMessageType('AuthDisableRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHDISABLEREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthDisableRequest)
  ))
_sym_db.RegisterMessage(AuthDisableRequest)

AuthenticateRequest = _reflection.GeneratedProtocolMessageType('AuthenticateRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHENTICATEREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthenticateRequest)
  ))
_sym_db.RegisterMessage(AuthenticateRequest)

AuthUserAddRequest = _reflection.GeneratedProtocolMessageType('AuthUserAddRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHUSERADDREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserAddRequest)
  ))
_sym_db.RegisterMessage(AuthUserAddRequest)

AuthUserGetRequest = _reflection.GeneratedProtocolMessageType('AuthUserGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHUSERGETREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserGetRequest)
  ))
_sym_db.RegisterMessage(AuthUserGetRequest)

AuthUserDeleteRequest = _reflection.GeneratedProtocolMessageType('AuthUserDeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHUSERDELETEREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserDeleteRequest)
  ))
_sym_db.RegisterMessage(AuthUserDeleteRequest)

AuthUserChangePasswordRequest = _reflection.GeneratedProtocolMessageType('AuthUserChangePasswordRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHUSERCHANGEPASSWORDREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserChangePasswordRequest)
  ))
_sym_db.RegisterMessage(AuthUserChangePasswordRequest)

AuthUserGrantRequest = _reflection.GeneratedProtocolMessageType('AuthUserGrantRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHUSERGRANTREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserGrantRequest)
  ))
_sym_db.RegisterMessage(AuthUserGrantRequest)

AuthUserRevokeRequest = _reflection.GeneratedProtocolMessageType('AuthUserRevokeRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHUSERREVOKEREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserRevokeRequest)
  ))
_sym_db.RegisterMessage(AuthUserRevokeRequest)

AuthRoleAddRequest = _reflection.GeneratedProtocolMessageType('AuthRoleAddRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHROLEADDREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleAddRequest)
  ))
_sym_db.RegisterMessage(AuthRoleAddRequest)

AuthRoleGetRequest = _reflection.GeneratedProtocolMessageType('AuthRoleGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHROLEGETREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleGetRequest)
  ))
_sym_db.RegisterMessage(AuthRoleGetRequest)

AuthRoleDeleteRequest = _reflection.GeneratedProtocolMessageType('AuthRoleDeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHROLEDELETEREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleDeleteRequest)
  ))
_sym_db.RegisterMessage(AuthRoleDeleteRequest)

AuthRoleGrantRequest = _reflection.GeneratedProtocolMessageType('AuthRoleGrantRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHROLEGRANTREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleGrantRequest)
  ))
_sym_db.RegisterMessage(AuthRoleGrantRequest)

AuthRoleRevokeRequest = _reflection.GeneratedProtocolMessageType('AuthRoleRevokeRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHROLEREVOKEREQUEST,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleRevokeRequest)
  ))
_sym_db.RegisterMessage(AuthRoleRevokeRequest)

AuthEnableResponse = _reflection.GeneratedProtocolMessageType('AuthEnableResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHENABLERESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthEnableResponse)
  ))
_sym_db.RegisterMessage(AuthEnableResponse)

AuthDisableResponse = _reflection.GeneratedProtocolMessageType('AuthDisableResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHDISABLERESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthDisableResponse)
  ))
_sym_db.RegisterMessage(AuthDisableResponse)

AuthenticateResponse = _reflection.GeneratedProtocolMessageType('AuthenticateResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHENTICATERESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthenticateResponse)
  ))
_sym_db.RegisterMessage(AuthenticateResponse)

AuthUserAddResponse = _reflection.GeneratedProtocolMessageType('AuthUserAddResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHUSERADDRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserAddResponse)
  ))
_sym_db.RegisterMessage(AuthUserAddResponse)

AuthUserGetResponse = _reflection.GeneratedProtocolMessageType('AuthUserGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHUSERGETRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserGetResponse)
  ))
_sym_db.RegisterMessage(AuthUserGetResponse)

AuthUserDeleteResponse = _reflection.GeneratedProtocolMessageType('AuthUserDeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHUSERDELETERESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserDeleteResponse)
  ))
_sym_db.RegisterMessage(AuthUserDeleteResponse)

AuthUserChangePasswordResponse = _reflection.GeneratedProtocolMessageType('AuthUserChangePasswordResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHUSERCHANGEPASSWORDRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserChangePasswordResponse)
  ))
_sym_db.RegisterMessage(AuthUserChangePasswordResponse)

AuthUserGrantResponse = _reflection.GeneratedProtocolMessageType('AuthUserGrantResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHUSERGRANTRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserGrantResponse)
  ))
_sym_db.RegisterMessage(AuthUserGrantResponse)

AuthUserRevokeResponse = _reflection.GeneratedProtocolMessageType('AuthUserRevokeResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHUSERREVOKERESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserRevokeResponse)
  ))
_sym_db.RegisterMessage(AuthUserRevokeResponse)

AuthRoleAddResponse = _reflection.GeneratedProtocolMessageType('AuthRoleAddResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHROLEADDRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleAddResponse)
  ))
_sym_db.RegisterMessage(AuthRoleAddResponse)

AuthRoleGetResponse = _reflection.GeneratedProtocolMessageType('AuthRoleGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHROLEGETRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleGetResponse)
  ))
_sym_db.RegisterMessage(AuthRoleGetResponse)

AuthRoleDeleteResponse = _reflection.GeneratedProtocolMessageType('AuthRoleDeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHROLEDELETERESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleDeleteResponse)
  ))
_sym_db.RegisterMessage(AuthRoleDeleteResponse)

AuthRoleGrantResponse = _reflection.GeneratedProtocolMessageType('AuthRoleGrantResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHROLEGRANTRESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleGrantResponse)
  ))
_sym_db.RegisterMessage(AuthRoleGrantResponse)

AuthRoleRevokeResponse = _reflection.GeneratedProtocolMessageType('AuthRoleRevokeResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHROLEREVOKERESPONSE,
  __module__ = 'etcd.etcdserver.etcdserverpb.rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleRevokeResponse)
  ))
_sym_db.RegisterMessage(AuthRoleRevokeResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\310\342\036\001\320\342\036\001'))
import abc
import six
from grpc.beta import implementations as beta_implementations
from grpc.framework.common import cardinality
from grpc.framework.interfaces.face import utilities as face_utilities

class BetaKVServicer(six.with_metaclass(abc.ABCMeta, object)):
  """<fill me in later!>"""
  @abc.abstractmethod
  def Range(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def Put(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def DeleteRange(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def Txn(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def Compact(self, request, context):
    raise NotImplementedError()

class BetaKVStub(six.with_metaclass(abc.ABCMeta, object)):
  """The interface to which stubs will conform."""
  @abc.abstractmethod
  def Range(self, request, timeout):
    raise NotImplementedError()
  Range.future = None
  @abc.abstractmethod
  def Put(self, request, timeout):
    raise NotImplementedError()
  Put.future = None
  @abc.abstractmethod
  def DeleteRange(self, request, timeout):
    raise NotImplementedError()
  DeleteRange.future = None
  @abc.abstractmethod
  def Txn(self, request, timeout):
    raise NotImplementedError()
  Txn.future = None
  @abc.abstractmethod
  def Compact(self, request, timeout):
    raise NotImplementedError()
  Compact.future = None

def beta_create_KV_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  request_deserializers = {
    ('etcdserverpb.KV', 'Compact'): etcd.etcdserver.etcdserverpb.rpc_pb2.CompactionRequest.FromString,
    ('etcdserverpb.KV', 'DeleteRange'): etcd.etcdserver.etcdserverpb.rpc_pb2.DeleteRangeRequest.FromString,
    ('etcdserverpb.KV', 'Put'): etcd.etcdserver.etcdserverpb.rpc_pb2.PutRequest.FromString,
    ('etcdserverpb.KV', 'Range'): etcd.etcdserver.etcdserverpb.rpc_pb2.RangeRequest.FromString,
    ('etcdserverpb.KV', 'Txn'): etcd.etcdserver.etcdserverpb.rpc_pb2.TxnRequest.FromString,
  }
  response_serializers = {
    ('etcdserverpb.KV', 'Compact'): etcd.etcdserver.etcdserverpb.rpc_pb2.CompactionResponse.SerializeToString,
    ('etcdserverpb.KV', 'DeleteRange'): etcd.etcdserver.etcdserverpb.rpc_pb2.DeleteRangeResponse.SerializeToString,
    ('etcdserverpb.KV', 'Put'): etcd.etcdserver.etcdserverpb.rpc_pb2.PutResponse.SerializeToString,
    ('etcdserverpb.KV', 'Range'): etcd.etcdserver.etcdserverpb.rpc_pb2.RangeResponse.SerializeToString,
    ('etcdserverpb.KV', 'Txn'): etcd.etcdserver.etcdserverpb.rpc_pb2.TxnResponse.SerializeToString,
  }
  method_implementations = {
    ('etcdserverpb.KV', 'Compact'): face_utilities.unary_unary_inline(servicer.Compact),
    ('etcdserverpb.KV', 'DeleteRange'): face_utilities.unary_unary_inline(servicer.DeleteRange),
    ('etcdserverpb.KV', 'Put'): face_utilities.unary_unary_inline(servicer.Put),
    ('etcdserverpb.KV', 'Range'): face_utilities.unary_unary_inline(servicer.Range),
    ('etcdserverpb.KV', 'Txn'): face_utilities.unary_unary_inline(servicer.Txn),
  }
  server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
  return beta_implementations.server(method_implementations, options=server_options)

def beta_create_KV_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  request_serializers = {
    ('etcdserverpb.KV', 'Compact'): etcd.etcdserver.etcdserverpb.rpc_pb2.CompactionRequest.SerializeToString,
    ('etcdserverpb.KV', 'DeleteRange'): etcd.etcdserver.etcdserverpb.rpc_pb2.DeleteRangeRequest.SerializeToString,
    ('etcdserverpb.KV', 'Put'): etcd.etcdserver.etcdserverpb.rpc_pb2.PutRequest.SerializeToString,
    ('etcdserverpb.KV', 'Range'): etcd.etcdserver.etcdserverpb.rpc_pb2.RangeRequest.SerializeToString,
    ('etcdserverpb.KV', 'Txn'): etcd.etcdserver.etcdserverpb.rpc_pb2.TxnRequest.SerializeToString,
  }
  response_deserializers = {
    ('etcdserverpb.KV', 'Compact'): etcd.etcdserver.etcdserverpb.rpc_pb2.CompactionResponse.FromString,
    ('etcdserverpb.KV', 'DeleteRange'): etcd.etcdserver.etcdserverpb.rpc_pb2.DeleteRangeResponse.FromString,
    ('etcdserverpb.KV', 'Put'): etcd.etcdserver.etcdserverpb.rpc_pb2.PutResponse.FromString,
    ('etcdserverpb.KV', 'Range'): etcd.etcdserver.etcdserverpb.rpc_pb2.RangeResponse.FromString,
    ('etcdserverpb.KV', 'Txn'): etcd.etcdserver.etcdserverpb.rpc_pb2.TxnResponse.FromString,
  }
  cardinalities = {
    'Compact': cardinality.Cardinality.UNARY_UNARY,
    'DeleteRange': cardinality.Cardinality.UNARY_UNARY,
    'Put': cardinality.Cardinality.UNARY_UNARY,
    'Range': cardinality.Cardinality.UNARY_UNARY,
    'Txn': cardinality.Cardinality.UNARY_UNARY,
  }
  stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
  return beta_implementations.dynamic_stub(channel, 'etcdserverpb.KV', cardinalities, options=stub_options)

class BetaWatchServicer(six.with_metaclass(abc.ABCMeta, object)):
  """<fill me in later!>"""
  @abc.abstractmethod
  def Watch(self, request_iterator, context):
    raise NotImplementedError()

class BetaWatchStub(six.with_metaclass(abc.ABCMeta, object)):
  """The interface to which stubs will conform."""
  @abc.abstractmethod
  def Watch(self, request_iterator, timeout):
    raise NotImplementedError()

def beta_create_Watch_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  request_deserializers = {
    ('etcdserverpb.Watch', 'Watch'): etcd.etcdserver.etcdserverpb.rpc_pb2.WatchRequest.FromString,
  }
  response_serializers = {
    ('etcdserverpb.Watch', 'Watch'): etcd.etcdserver.etcdserverpb.rpc_pb2.WatchResponse.SerializeToString,
  }
  method_implementations = {
    ('etcdserverpb.Watch', 'Watch'): face_utilities.stream_stream_inline(servicer.Watch),
  }
  server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
  return beta_implementations.server(method_implementations, options=server_options)

def beta_create_Watch_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  request_serializers = {
    ('etcdserverpb.Watch', 'Watch'): etcd.etcdserver.etcdserverpb.rpc_pb2.WatchRequest.SerializeToString,
  }
  response_deserializers = {
    ('etcdserverpb.Watch', 'Watch'): etcd.etcdserver.etcdserverpb.rpc_pb2.WatchResponse.FromString,
  }
  cardinalities = {
    'Watch': cardinality.Cardinality.STREAM_STREAM,
  }
  stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
  return beta_implementations.dynamic_stub(channel, 'etcdserverpb.Watch', cardinalities, options=stub_options)

class BetaLeaseServicer(six.with_metaclass(abc.ABCMeta, object)):
  """<fill me in later!>"""
  @abc.abstractmethod
  def LeaseGrant(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def LeaseRevoke(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def LeaseKeepAlive(self, request_iterator, context):
    raise NotImplementedError()

class BetaLeaseStub(six.with_metaclass(abc.ABCMeta, object)):
  """The interface to which stubs will conform."""
  @abc.abstractmethod
  def LeaseGrant(self, request, timeout):
    raise NotImplementedError()
  LeaseGrant.future = None
  @abc.abstractmethod
  def LeaseRevoke(self, request, timeout):
    raise NotImplementedError()
  LeaseRevoke.future = None
  @abc.abstractmethod
  def LeaseKeepAlive(self, request_iterator, timeout):
    raise NotImplementedError()

def beta_create_Lease_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  request_deserializers = {
    ('etcdserverpb.Lease', 'LeaseGrant'): etcd.etcdserver.etcdserverpb.rpc_pb2.LeaseGrantRequest.FromString,
    ('etcdserverpb.Lease', 'LeaseKeepAlive'): etcd.etcdserver.etcdserverpb.rpc_pb2.LeaseKeepAliveRequest.FromString,
    ('etcdserverpb.Lease', 'LeaseRevoke'): etcd.etcdserver.etcdserverpb.rpc_pb2.LeaseRevokeRequest.FromString,
  }
  response_serializers = {
    ('etcdserverpb.Lease', 'LeaseGrant'): etcd.etcdserver.etcdserverpb.rpc_pb2.LeaseGrantResponse.SerializeToString,
    ('etcdserverpb.Lease', 'LeaseKeepAlive'): etcd.etcdserver.etcdserverpb.rpc_pb2.LeaseKeepAliveResponse.SerializeToString,
    ('etcdserverpb.Lease', 'LeaseRevoke'): etcd.etcdserver.etcdserverpb.rpc_pb2.LeaseRevokeResponse.SerializeToString,
  }
  method_implementations = {
    ('etcdserverpb.Lease', 'LeaseGrant'): face_utilities.unary_unary_inline(servicer.LeaseGrant),
    ('etcdserverpb.Lease', 'LeaseKeepAlive'): face_utilities.stream_stream_inline(servicer.LeaseKeepAlive),
    ('etcdserverpb.Lease', 'LeaseRevoke'): face_utilities.unary_unary_inline(servicer.LeaseRevoke),
  }
  server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
  return beta_implementations.server(method_implementations, options=server_options)

def beta_create_Lease_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  request_serializers = {
    ('etcdserverpb.Lease', 'LeaseGrant'): etcd.etcdserver.etcdserverpb.rpc_pb2.LeaseGrantRequest.SerializeToString,
    ('etcdserverpb.Lease', 'LeaseKeepAlive'): etcd.etcdserver.etcdserverpb.rpc_pb2.LeaseKeepAliveRequest.SerializeToString,
    ('etcdserverpb.Lease', 'LeaseRevoke'): etcd.etcdserver.etcdserverpb.rpc_pb2.LeaseRevokeRequest.SerializeToString,
  }
  response_deserializers = {
    ('etcdserverpb.Lease', 'LeaseGrant'): etcd.etcdserver.etcdserverpb.rpc_pb2.LeaseGrantResponse.FromString,
    ('etcdserverpb.Lease', 'LeaseKeepAlive'): etcd.etcdserver.etcdserverpb.rpc_pb2.LeaseKeepAliveResponse.FromString,
    ('etcdserverpb.Lease', 'LeaseRevoke'): etcd.etcdserver.etcdserverpb.rpc_pb2.LeaseRevokeResponse.FromString,
  }
  cardinalities = {
    'LeaseGrant': cardinality.Cardinality.UNARY_UNARY,
    'LeaseKeepAlive': cardinality.Cardinality.STREAM_STREAM,
    'LeaseRevoke': cardinality.Cardinality.UNARY_UNARY,
  }
  stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
  return beta_implementations.dynamic_stub(channel, 'etcdserverpb.Lease', cardinalities, options=stub_options)

class BetaClusterServicer(six.with_metaclass(abc.ABCMeta, object)):
  """<fill me in later!>"""
  @abc.abstractmethod
  def MemberAdd(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def MemberRemove(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def MemberUpdate(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def MemberList(self, request, context):
    raise NotImplementedError()

class BetaClusterStub(six.with_metaclass(abc.ABCMeta, object)):
  """The interface to which stubs will conform."""
  @abc.abstractmethod
  def MemberAdd(self, request, timeout):
    raise NotImplementedError()
  MemberAdd.future = None
  @abc.abstractmethod
  def MemberRemove(self, request, timeout):
    raise NotImplementedError()
  MemberRemove.future = None
  @abc.abstractmethod
  def MemberUpdate(self, request, timeout):
    raise NotImplementedError()
  MemberUpdate.future = None
  @abc.abstractmethod
  def MemberList(self, request, timeout):
    raise NotImplementedError()
  MemberList.future = None

def beta_create_Cluster_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  request_deserializers = {
    ('etcdserverpb.Cluster', 'MemberAdd'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberAddRequest.FromString,
    ('etcdserverpb.Cluster', 'MemberList'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberListRequest.FromString,
    ('etcdserverpb.Cluster', 'MemberRemove'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberRemoveRequest.FromString,
    ('etcdserverpb.Cluster', 'MemberUpdate'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberUpdateRequest.FromString,
  }
  response_serializers = {
    ('etcdserverpb.Cluster', 'MemberAdd'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberAddResponse.SerializeToString,
    ('etcdserverpb.Cluster', 'MemberList'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberListResponse.SerializeToString,
    ('etcdserverpb.Cluster', 'MemberRemove'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberRemoveResponse.SerializeToString,
    ('etcdserverpb.Cluster', 'MemberUpdate'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberUpdateResponse.SerializeToString,
  }
  method_implementations = {
    ('etcdserverpb.Cluster', 'MemberAdd'): face_utilities.unary_unary_inline(servicer.MemberAdd),
    ('etcdserverpb.Cluster', 'MemberList'): face_utilities.unary_unary_inline(servicer.MemberList),
    ('etcdserverpb.Cluster', 'MemberRemove'): face_utilities.unary_unary_inline(servicer.MemberRemove),
    ('etcdserverpb.Cluster', 'MemberUpdate'): face_utilities.unary_unary_inline(servicer.MemberUpdate),
  }
  server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
  return beta_implementations.server(method_implementations, options=server_options)

def beta_create_Cluster_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  request_serializers = {
    ('etcdserverpb.Cluster', 'MemberAdd'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberAddRequest.SerializeToString,
    ('etcdserverpb.Cluster', 'MemberList'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberListRequest.SerializeToString,
    ('etcdserverpb.Cluster', 'MemberRemove'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberRemoveRequest.SerializeToString,
    ('etcdserverpb.Cluster', 'MemberUpdate'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberUpdateRequest.SerializeToString,
  }
  response_deserializers = {
    ('etcdserverpb.Cluster', 'MemberAdd'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberAddResponse.FromString,
    ('etcdserverpb.Cluster', 'MemberList'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberListResponse.FromString,
    ('etcdserverpb.Cluster', 'MemberRemove'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberRemoveResponse.FromString,
    ('etcdserverpb.Cluster', 'MemberUpdate'): etcd.etcdserver.etcdserverpb.rpc_pb2.MemberUpdateResponse.FromString,
  }
  cardinalities = {
    'MemberAdd': cardinality.Cardinality.UNARY_UNARY,
    'MemberList': cardinality.Cardinality.UNARY_UNARY,
    'MemberRemove': cardinality.Cardinality.UNARY_UNARY,
    'MemberUpdate': cardinality.Cardinality.UNARY_UNARY,
  }
  stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
  return beta_implementations.dynamic_stub(channel, 'etcdserverpb.Cluster', cardinalities, options=stub_options)

class BetaMaintenanceServicer(six.with_metaclass(abc.ABCMeta, object)):
  """<fill me in later!>"""
  @abc.abstractmethod
  def Alarm(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def Status(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def Defragment(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def Hash(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def Snapshot(self, request, context):
    raise NotImplementedError()

class BetaMaintenanceStub(six.with_metaclass(abc.ABCMeta, object)):
  """The interface to which stubs will conform."""
  @abc.abstractmethod
  def Alarm(self, request, timeout):
    raise NotImplementedError()
  Alarm.future = None
  @abc.abstractmethod
  def Status(self, request, timeout):
    raise NotImplementedError()
  Status.future = None
  @abc.abstractmethod
  def Defragment(self, request, timeout):
    raise NotImplementedError()
  Defragment.future = None
  @abc.abstractmethod
  def Hash(self, request, timeout):
    raise NotImplementedError()
  Hash.future = None
  @abc.abstractmethod
  def Snapshot(self, request, timeout):
    raise NotImplementedError()

def beta_create_Maintenance_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  request_deserializers = {
    ('etcdserverpb.Maintenance', 'Alarm'): etcd.etcdserver.etcdserverpb.rpc_pb2.AlarmRequest.FromString,
    ('etcdserverpb.Maintenance', 'Defragment'): etcd.etcdserver.etcdserverpb.rpc_pb2.DefragmentRequest.FromString,
    ('etcdserverpb.Maintenance', 'Hash'): etcd.etcdserver.etcdserverpb.rpc_pb2.HashRequest.FromString,
    ('etcdserverpb.Maintenance', 'Snapshot'): etcd.etcdserver.etcdserverpb.rpc_pb2.SnapshotRequest.FromString,
    ('etcdserverpb.Maintenance', 'Status'): etcd.etcdserver.etcdserverpb.rpc_pb2.StatusRequest.FromString,
  }
  response_serializers = {
    ('etcdserverpb.Maintenance', 'Alarm'): etcd.etcdserver.etcdserverpb.rpc_pb2.AlarmResponse.SerializeToString,
    ('etcdserverpb.Maintenance', 'Defragment'): etcd.etcdserver.etcdserverpb.rpc_pb2.DefragmentResponse.SerializeToString,
    ('etcdserverpb.Maintenance', 'Hash'): etcd.etcdserver.etcdserverpb.rpc_pb2.HashResponse.SerializeToString,
    ('etcdserverpb.Maintenance', 'Snapshot'): etcd.etcdserver.etcdserverpb.rpc_pb2.SnapshotResponse.SerializeToString,
    ('etcdserverpb.Maintenance', 'Status'): etcd.etcdserver.etcdserverpb.rpc_pb2.StatusResponse.SerializeToString,
  }
  method_implementations = {
    ('etcdserverpb.Maintenance', 'Alarm'): face_utilities.unary_unary_inline(servicer.Alarm),
    ('etcdserverpb.Maintenance', 'Defragment'): face_utilities.unary_unary_inline(servicer.Defragment),
    ('etcdserverpb.Maintenance', 'Hash'): face_utilities.unary_unary_inline(servicer.Hash),
    ('etcdserverpb.Maintenance', 'Snapshot'): face_utilities.unary_stream_inline(servicer.Snapshot),
    ('etcdserverpb.Maintenance', 'Status'): face_utilities.unary_unary_inline(servicer.Status),
  }
  server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
  return beta_implementations.server(method_implementations, options=server_options)

def beta_create_Maintenance_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  request_serializers = {
    ('etcdserverpb.Maintenance', 'Alarm'): etcd.etcdserver.etcdserverpb.rpc_pb2.AlarmRequest.SerializeToString,
    ('etcdserverpb.Maintenance', 'Defragment'): etcd.etcdserver.etcdserverpb.rpc_pb2.DefragmentRequest.SerializeToString,
    ('etcdserverpb.Maintenance', 'Hash'): etcd.etcdserver.etcdserverpb.rpc_pb2.HashRequest.SerializeToString,
    ('etcdserverpb.Maintenance', 'Snapshot'): etcd.etcdserver.etcdserverpb.rpc_pb2.SnapshotRequest.SerializeToString,
    ('etcdserverpb.Maintenance', 'Status'): etcd.etcdserver.etcdserverpb.rpc_pb2.StatusRequest.SerializeToString,
  }
  response_deserializers = {
    ('etcdserverpb.Maintenance', 'Alarm'): etcd.etcdserver.etcdserverpb.rpc_pb2.AlarmResponse.FromString,
    ('etcdserverpb.Maintenance', 'Defragment'): etcd.etcdserver.etcdserverpb.rpc_pb2.DefragmentResponse.FromString,
    ('etcdserverpb.Maintenance', 'Hash'): etcd.etcdserver.etcdserverpb.rpc_pb2.HashResponse.FromString,
    ('etcdserverpb.Maintenance', 'Snapshot'): etcd.etcdserver.etcdserverpb.rpc_pb2.SnapshotResponse.FromString,
    ('etcdserverpb.Maintenance', 'Status'): etcd.etcdserver.etcdserverpb.rpc_pb2.StatusResponse.FromString,
  }
  cardinalities = {
    'Alarm': cardinality.Cardinality.UNARY_UNARY,
    'Defragment': cardinality.Cardinality.UNARY_UNARY,
    'Hash': cardinality.Cardinality.UNARY_UNARY,
    'Snapshot': cardinality.Cardinality.UNARY_STREAM,
    'Status': cardinality.Cardinality.UNARY_UNARY,
  }
  stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
  return beta_implementations.dynamic_stub(channel, 'etcdserverpb.Maintenance', cardinalities, options=stub_options)

class BetaAuthServicer(six.with_metaclass(abc.ABCMeta, object)):
  """<fill me in later!>"""
  @abc.abstractmethod
  def AuthEnable(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def AuthDisable(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def Authenticate(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def UserAdd(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def UserGet(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def UserDelete(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def UserChangePassword(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def UserGrant(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def UserRevoke(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def RoleAdd(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def RoleGet(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def RoleDelete(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def RoleGrant(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def RoleRevoke(self, request, context):
    raise NotImplementedError()

class BetaAuthStub(six.with_metaclass(abc.ABCMeta, object)):
  """The interface to which stubs will conform."""
  @abc.abstractmethod
  def AuthEnable(self, request, timeout):
    raise NotImplementedError()
  AuthEnable.future = None
  @abc.abstractmethod
  def AuthDisable(self, request, timeout):
    raise NotImplementedError()
  AuthDisable.future = None
  @abc.abstractmethod
  def Authenticate(self, request, timeout):
    raise NotImplementedError()
  Authenticate.future = None
  @abc.abstractmethod
  def UserAdd(self, request, timeout):
    raise NotImplementedError()
  UserAdd.future = None
  @abc.abstractmethod
  def UserGet(self, request, timeout):
    raise NotImplementedError()
  UserGet.future = None
  @abc.abstractmethod
  def UserDelete(self, request, timeout):
    raise NotImplementedError()
  UserDelete.future = None
  @abc.abstractmethod
  def UserChangePassword(self, request, timeout):
    raise NotImplementedError()
  UserChangePassword.future = None
  @abc.abstractmethod
  def UserGrant(self, request, timeout):
    raise NotImplementedError()
  UserGrant.future = None
  @abc.abstractmethod
  def UserRevoke(self, request, timeout):
    raise NotImplementedError()
  UserRevoke.future = None
  @abc.abstractmethod
  def RoleAdd(self, request, timeout):
    raise NotImplementedError()
  RoleAdd.future = None
  @abc.abstractmethod
  def RoleGet(self, request, timeout):
    raise NotImplementedError()
  RoleGet.future = None
  @abc.abstractmethod
  def RoleDelete(self, request, timeout):
    raise NotImplementedError()
  RoleDelete.future = None
  @abc.abstractmethod
  def RoleGrant(self, request, timeout):
    raise NotImplementedError()
  RoleGrant.future = None
  @abc.abstractmethod
  def RoleRevoke(self, request, timeout):
    raise NotImplementedError()
  RoleRevoke.future = None

def beta_create_Auth_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  request_deserializers = {
    ('etcdserverpb.Auth', 'AuthDisable'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthDisableRequest.FromString,
    ('etcdserverpb.Auth', 'AuthEnable'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthEnableRequest.FromString,
    ('etcdserverpb.Auth', 'Authenticate'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthenticateRequest.FromString,
    ('etcdserverpb.Auth', 'RoleAdd'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleAddRequest.FromString,
    ('etcdserverpb.Auth', 'RoleDelete'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleDeleteRequest.FromString,
    ('etcdserverpb.Auth', 'RoleGet'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleGetRequest.FromString,
    ('etcdserverpb.Auth', 'RoleGrant'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleGrantRequest.FromString,
    ('etcdserverpb.Auth', 'RoleRevoke'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleRevokeRequest.FromString,
    ('etcdserverpb.Auth', 'UserAdd'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserAddRequest.FromString,
    ('etcdserverpb.Auth', 'UserChangePassword'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserChangePasswordRequest.FromString,
    ('etcdserverpb.Auth', 'UserDelete'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserDeleteRequest.FromString,
    ('etcdserverpb.Auth', 'UserGet'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserGetRequest.FromString,
    ('etcdserverpb.Auth', 'UserGrant'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserGrantRequest.FromString,
    ('etcdserverpb.Auth', 'UserRevoke'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserRevokeRequest.FromString,
  }
  response_serializers = {
    ('etcdserverpb.Auth', 'AuthDisable'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthDisableResponse.SerializeToString,
    ('etcdserverpb.Auth', 'AuthEnable'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthEnableResponse.SerializeToString,
    ('etcdserverpb.Auth', 'Authenticate'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthenticateResponse.SerializeToString,
    ('etcdserverpb.Auth', 'RoleAdd'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleAddResponse.SerializeToString,
    ('etcdserverpb.Auth', 'RoleDelete'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleDeleteResponse.SerializeToString,
    ('etcdserverpb.Auth', 'RoleGet'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleGetResponse.SerializeToString,
    ('etcdserverpb.Auth', 'RoleGrant'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleGrantResponse.SerializeToString,
    ('etcdserverpb.Auth', 'RoleRevoke'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleRevokeResponse.SerializeToString,
    ('etcdserverpb.Auth', 'UserAdd'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserAddResponse.SerializeToString,
    ('etcdserverpb.Auth', 'UserChangePassword'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserChangePasswordResponse.SerializeToString,
    ('etcdserverpb.Auth', 'UserDelete'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserDeleteResponse.SerializeToString,
    ('etcdserverpb.Auth', 'UserGet'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserGetResponse.SerializeToString,
    ('etcdserverpb.Auth', 'UserGrant'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserGrantResponse.SerializeToString,
    ('etcdserverpb.Auth', 'UserRevoke'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserRevokeResponse.SerializeToString,
  }
  method_implementations = {
    ('etcdserverpb.Auth', 'AuthDisable'): face_utilities.unary_unary_inline(servicer.AuthDisable),
    ('etcdserverpb.Auth', 'AuthEnable'): face_utilities.unary_unary_inline(servicer.AuthEnable),
    ('etcdserverpb.Auth', 'Authenticate'): face_utilities.unary_unary_inline(servicer.Authenticate),
    ('etcdserverpb.Auth', 'RoleAdd'): face_utilities.unary_unary_inline(servicer.RoleAdd),
    ('etcdserverpb.Auth', 'RoleDelete'): face_utilities.unary_unary_inline(servicer.RoleDelete),
    ('etcdserverpb.Auth', 'RoleGet'): face_utilities.unary_unary_inline(servicer.RoleGet),
    ('etcdserverpb.Auth', 'RoleGrant'): face_utilities.unary_unary_inline(servicer.RoleGrant),
    ('etcdserverpb.Auth', 'RoleRevoke'): face_utilities.unary_unary_inline(servicer.RoleRevoke),
    ('etcdserverpb.Auth', 'UserAdd'): face_utilities.unary_unary_inline(servicer.UserAdd),
    ('etcdserverpb.Auth', 'UserChangePassword'): face_utilities.unary_unary_inline(servicer.UserChangePassword),
    ('etcdserverpb.Auth', 'UserDelete'): face_utilities.unary_unary_inline(servicer.UserDelete),
    ('etcdserverpb.Auth', 'UserGet'): face_utilities.unary_unary_inline(servicer.UserGet),
    ('etcdserverpb.Auth', 'UserGrant'): face_utilities.unary_unary_inline(servicer.UserGrant),
    ('etcdserverpb.Auth', 'UserRevoke'): face_utilities.unary_unary_inline(servicer.UserRevoke),
  }
  server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
  return beta_implementations.server(method_implementations, options=server_options)

def beta_create_Auth_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  import etcd.etcdserver.etcdserverpb.rpc_pb2
  request_serializers = {
    ('etcdserverpb.Auth', 'AuthDisable'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthDisableRequest.SerializeToString,
    ('etcdserverpb.Auth', 'AuthEnable'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthEnableRequest.SerializeToString,
    ('etcdserverpb.Auth', 'Authenticate'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthenticateRequest.SerializeToString,
    ('etcdserverpb.Auth', 'RoleAdd'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleAddRequest.SerializeToString,
    ('etcdserverpb.Auth', 'RoleDelete'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleDeleteRequest.SerializeToString,
    ('etcdserverpb.Auth', 'RoleGet'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleGetRequest.SerializeToString,
    ('etcdserverpb.Auth', 'RoleGrant'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleGrantRequest.SerializeToString,
    ('etcdserverpb.Auth', 'RoleRevoke'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleRevokeRequest.SerializeToString,
    ('etcdserverpb.Auth', 'UserAdd'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserAddRequest.SerializeToString,
    ('etcdserverpb.Auth', 'UserChangePassword'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserChangePasswordRequest.SerializeToString,
    ('etcdserverpb.Auth', 'UserDelete'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserDeleteRequest.SerializeToString,
    ('etcdserverpb.Auth', 'UserGet'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserGetRequest.SerializeToString,
    ('etcdserverpb.Auth', 'UserGrant'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserGrantRequest.SerializeToString,
    ('etcdserverpb.Auth', 'UserRevoke'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserRevokeRequest.SerializeToString,
  }
  response_deserializers = {
    ('etcdserverpb.Auth', 'AuthDisable'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthDisableResponse.FromString,
    ('etcdserverpb.Auth', 'AuthEnable'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthEnableResponse.FromString,
    ('etcdserverpb.Auth', 'Authenticate'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthenticateResponse.FromString,
    ('etcdserverpb.Auth', 'RoleAdd'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleAddResponse.FromString,
    ('etcdserverpb.Auth', 'RoleDelete'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleDeleteResponse.FromString,
    ('etcdserverpb.Auth', 'RoleGet'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleGetResponse.FromString,
    ('etcdserverpb.Auth', 'RoleGrant'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleGrantResponse.FromString,
    ('etcdserverpb.Auth', 'RoleRevoke'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthRoleRevokeResponse.FromString,
    ('etcdserverpb.Auth', 'UserAdd'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserAddResponse.FromString,
    ('etcdserverpb.Auth', 'UserChangePassword'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserChangePasswordResponse.FromString,
    ('etcdserverpb.Auth', 'UserDelete'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserDeleteResponse.FromString,
    ('etcdserverpb.Auth', 'UserGet'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserGetResponse.FromString,
    ('etcdserverpb.Auth', 'UserGrant'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserGrantResponse.FromString,
    ('etcdserverpb.Auth', 'UserRevoke'): etcd.etcdserver.etcdserverpb.rpc_pb2.AuthUserRevokeResponse.FromString,
  }
  cardinalities = {
    'AuthDisable': cardinality.Cardinality.UNARY_UNARY,
    'AuthEnable': cardinality.Cardinality.UNARY_UNARY,
    'Authenticate': cardinality.Cardinality.UNARY_UNARY,
    'RoleAdd': cardinality.Cardinality.UNARY_UNARY,
    'RoleDelete': cardinality.Cardinality.UNARY_UNARY,
    'RoleGet': cardinality.Cardinality.UNARY_UNARY,
    'RoleGrant': cardinality.Cardinality.UNARY_UNARY,
    'RoleRevoke': cardinality.Cardinality.UNARY_UNARY,
    'UserAdd': cardinality.Cardinality.UNARY_UNARY,
    'UserChangePassword': cardinality.Cardinality.UNARY_UNARY,
    'UserDelete': cardinality.Cardinality.UNARY_UNARY,
    'UserGet': cardinality.Cardinality.UNARY_UNARY,
    'UserGrant': cardinality.Cardinality.UNARY_UNARY,
    'UserRevoke': cardinality.Cardinality.UNARY_UNARY,
  }
  stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
  return beta_implementations.dynamic_stub(channel, 'etcdserverpb.Auth', cardinalities, options=stub_options)
# @@protoc_insertion_point(module_scope)
